;;; thing-after-point-utils.el  --- more thing-at-point edit functions

;; Version: 1.6

;; Copyright (C) 2006, 2007 Andreas Roehler

;; Author: Andreas Roehler <andreas.roehler@easy-emacs.de>

;; Keywords: convenience

;; This file is free software; you can redistribute it

;; and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation; either version 3, or (at your option) any later version.

;; This file is distributed in the hope that it will be useful,
;; but WITHOUT ANY WARRANTY; without even the implied warranty of
;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
;; GNU General Public License for more details.

;; You should have received a copy of the GNU General Public License
;; along with GNU Emacs; see the file COPYING.  If not, write to
;; the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
;; Boston, MA 02110-1301, USA.

;;; Commentary:

;; Information is given with thingatpt-utils-base.el

(require 'thingatpt-utils-base)



;;;###autoload
(defun alnum-afpt (&optional arg ispec) 
  "Returns alnum after point if any, nil otherwise"
  (interactive "P\np")
  (or arg (setq arg 1)) 
  (save-excursion
    (thatpt 'alnum arg ispec)))

;;;###autoload
(defun bounds-of-alnum-afpt (&optional arg ispec) 
  "Returns border of alnum after point if any, nil otherwise "
  (interactive "P\np")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward "^[:alnum:]")
      (let ((alnum (thatpt-bounds 'alnum arg ispec)))
	(when ispec (message "   %s" alnum))
	alnum))))

;;;###autoload
(defun alnum-afpt-beginning-position (&optional arg ispec) 
  "Returns beginning of alnum after point if any, nil otherwise "
  (interactive "P\np")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward "^[:alnum:]")
      (thatpt-beginning 'alnum arg ispec))))

;;;###autoload
(defun alnum-afpt-end-position (&optional arg ispec) 
  "Returns end position of alnum after point if any, nil otherwise "
  (interactive "P\np")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward "^[:alnum:]")
      (thatpt-end 'alnum arg ispec))))

;;;###autoload
(defun length-of-alnum-afpt (&optional arg ispec) 
  "Returns end position of alnum after point if any, nil otherwise "
  (interactive "P\np")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward "^[:alnum:]")
      (thatpt-length 'alnum arg ispec))))

;;;###autoload
(defun copy-alnum-afpt (&optional arg ispec) 
  "Returns a copy of alnum after point if any, nil otherwise "
  (interactive "P\np")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward "^[:alnum:]")
      (thatpt-copy 'alnum arg ispec))))

;;;###autoload
(defun separate-alnum-afpt (&optional arg ispec) 
  "Returns a copy of alnum after point if any, nil otherwise "
  (interactive "P\np")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward "^[:alnum:]")
      (thatpt-separate 'alnum arg ispec))))

;;;###autoload
(defun comment-alnum-afpt (&optional arg ispec) 
  "Returns a copy of alnum after point if any, nil otherwise "
  (interactive "P\np")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward "^[:alnum:]")
      (thatpt-comment 'alnum arg ispec))))

;;;###autoload
(defun doublequote-alnum-afpt (&optional arg ispec) 
  "Doublequotes alnum after point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'alnum 'doublequote arg ispec))

;;;###autoload
(defun singlequote-alnum-afpt (&optional arg ispec) 
  "Singlequotes alnum after point if any, does nothing otherwise " 
  (interactive "P\np")
  (thatpt-delim 'alnum 'singlequote arg ispec))

;;;###autoload
(defun parenthese-alnum-afpt (&optional arg ispec) 
  "Parentizes alnum after point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'alnum 'parentize arg ispec))

;;;###autoload
(defun brace-alnum-afpt (&optional arg ispec) 
  "Braces alnum after point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'alnum 'brace arg ispec))

;;;###autoload
(defun bracket-alnum-afpt (&optional arg ispec) 
  "Brackets alnum after point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'alnum 'bracket arg ispec))

;;;###autoload
(defun mark-alnum-afpt ()
  "Marks alnum after point if any, does nothing otherwise "
  (interactive "*")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward "^[:alnum:]")
      (thatpt-mark 'alnum))))

;;;###autoload
(defun forward-alnum-afpt (&optional arg ispec) 
  "Moves forward over alnum after point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-forward 'alnum arg ispec))


;;;###autoload
(defun alpha-afpt (&optional arg ispec) 
  "Returns alpha after point if any, nil otherwise"
  (interactive "P\np")
  (or arg (setq arg 1)) 
  (save-excursion
    (thatpt 'alpha arg ispec)))

;;;###autoload
(defun bounds-of-alpha-afpt (&optional arg ispec) 
  "Returns border of alpha after point if any, nil otherwise "
  (interactive "P\np")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward "^[:alpha:]")
      (let ((alpha (thatpt-bounds 'alpha arg ispec)))
	(when ispec (message "   %s" alpha))
	alpha))))

;;;###autoload
(defun alpha-afpt-beginning-position (&optional arg ispec) 
  "Returns beginning of alpha after point if any, nil otherwise "
  (interactive "P\np")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward "^[:alpha:]")
      (thatpt-beginning 'alpha arg ispec))))

;;;###autoload
(defun alpha-afpt-end-position (&optional arg ispec) 
  "Returns end position of alpha after point if any, nil otherwise "
  (interactive "P\np")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward "^[:alpha:]")
      (thatpt-end 'alpha arg ispec))))

;;;###autoload
(defun length-of-alpha-afpt (&optional arg ispec) 
  "Returns end position of alpha after point if any, nil otherwise "
  (interactive "P\np")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward "^[:alpha:]")
      (thatpt-length 'alpha arg ispec))))

;;;###autoload
(defun copy-alpha-afpt (&optional arg ispec) 
  "Returns a copy of alpha after point if any, nil otherwise "
  (interactive "P\np")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward "^[:alpha:]")
      (thatpt-copy 'alpha arg ispec))))

;;;###autoload
(defun separate-alpha-afpt (&optional arg ispec) 
  "Returns a copy of alpha after point if any, nil otherwise "
  (interactive "P\np")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward "^[:alpha:]")
      (thatpt-separate 'alpha arg ispec))))

;;;###autoload
(defun comment-alpha-afpt (&optional arg ispec) 
  "Returns a copy of alpha after point if any, nil otherwise "
  (interactive "P\np")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward "^[:alpha:]")
      (thatpt-comment 'alpha arg ispec))))

;;;###autoload
(defun doublequote-alpha-afpt (&optional arg ispec) 
  "Doublequotes alpha after point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'alpha 'doublequote arg ispec))

;;;###autoload
(defun singlequote-alpha-afpt (&optional arg ispec) 
  "Singlequotes alpha after point if any, does nothing otherwise " 
  (interactive "P\np")
  (thatpt-delim 'alpha 'singlequote arg ispec))

;;;###autoload
(defun parenthese-alpha-afpt (&optional arg ispec) 
  "Parentizes alpha after point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'alpha 'parentize arg ispec))

;;;###autoload
(defun brace-alpha-afpt (&optional arg ispec) 
  "Braces alpha after point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'alpha 'brace arg ispec))

;;;###autoload
(defun bracket-alpha-afpt (&optional arg ispec) 
  "Brackets alpha after point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'alpha 'bracket arg ispec))

;;;###autoload
(defun mark-alpha-afpt ()
  "Marks alpha after point if any, does nothing otherwise "
  (interactive "*")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward "^[:alpha:]")
      (thatpt-mark 'alpha))))

;;;###autoload
(defun forward-alpha-afpt (&optional arg ispec) 
  "Moves forward over alpha after point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-forward 'alpha arg ispec))


;;;###autoload
(defun ascii-afpt (&optional arg ispec) 
  "Returns ascii after point if any, nil otherwise"
  (interactive "P\np")
  (or arg (setq arg 1)) 
  (save-excursion
    (thatpt 'ascii arg ispec)))

;;;###autoload
(defun bounds-of-ascii-afpt (&optional arg ispec) 
  "Returns border of ascii after point if any, nil otherwise "
  (interactive "P\np")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward "^[:ascii:]")
      (let ((ascii (thatpt-bounds 'ascii arg ispec)))
	(when ispec (message "   %s" ascii))
	ascii))))

;;;###autoload
(defun ascii-afpt-beginning-position (&optional arg ispec) 
  "Returns beginning of ascii after point if any, nil otherwise "
  (interactive "P\np")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward "^[:ascii:]")
      (thatpt-beginning 'ascii arg ispec))))

;;;###autoload
(defun ascii-afpt-end-position (&optional arg ispec) 
  "Returns end position of ascii after point if any, nil otherwise "
  (interactive "P\np")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward "^[:ascii:]")
      (thatpt-end 'ascii arg ispec))))

;;;###autoload
(defun length-of-ascii-afpt (&optional arg ispec) 
  "Returns end position of ascii after point if any, nil otherwise "
  (interactive "P\np")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward "^[:ascii:]")
      (thatpt-length 'ascii arg ispec))))

;;;###autoload
(defun copy-ascii-afpt (&optional arg ispec) 
  "Returns a copy of ascii after point if any, nil otherwise "
  (interactive "P\np")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward "^[:ascii:]")
      (thatpt-copy 'ascii arg ispec))))

;;;###autoload
(defun separate-ascii-afpt (&optional arg ispec) 
  "Returns a copy of ascii after point if any, nil otherwise "
  (interactive "P\np")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward "^[:ascii:]")
      (thatpt-separate 'ascii arg ispec))))

;;;###autoload
(defun comment-ascii-afpt (&optional arg ispec) 
  "Returns a copy of ascii after point if any, nil otherwise "
  (interactive "P\np")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward "^[:ascii:]")
      (thatpt-comment 'ascii arg ispec))))

;;;###autoload
(defun doublequote-ascii-afpt (&optional arg ispec) 
  "Doublequotes ascii after point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'ascii 'doublequote arg ispec))

;;;###autoload
(defun singlequote-ascii-afpt (&optional arg ispec) 
  "Singlequotes ascii after point if any, does nothing otherwise " 
  (interactive "P\np")
  (thatpt-delim 'ascii 'singlequote arg ispec))

;;;###autoload
(defun parenthese-ascii-afpt (&optional arg ispec) 
  "Parentizes ascii after point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'ascii 'parentize arg ispec))

;;;###autoload
(defun brace-ascii-afpt (&optional arg ispec) 
  "Braces ascii after point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'ascii 'brace arg ispec))

;;;###autoload
(defun bracket-ascii-afpt (&optional arg ispec) 
  "Brackets ascii after point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'ascii 'bracket arg ispec))

;;;###autoload
(defun mark-ascii-afpt ()
  "Marks ascii after point if any, does nothing otherwise "
  (interactive "*")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward "^[:ascii:]")
      (thatpt-mark 'ascii))))

;;;###autoload
(defun forward-ascii-afpt (&optional arg ispec) 
  "Moves forward over ascii after point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-forward 'ascii arg ispec))


;;;###autoload
(defun blank-afpt (&optional arg ispec) 
  "Returns blank after point if any, nil otherwise"
  (interactive "P\np")
  (or arg (setq arg 1)) 
  (save-excursion
    (thatpt 'blank arg ispec)))

;;;###autoload
(defun bounds-of-blank-afpt (&optional arg ispec) 
  "Returns border of blank after point if any, nil otherwise "
  (interactive "P\np")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward "^[:blank:]")
      (let ((blank (thatpt-bounds 'blank arg ispec)))
	(when ispec (message "   %s" blank))
	blank))))

;;;###autoload
(defun blank-afpt-beginning-position (&optional arg ispec) 
  "Returns beginning of blank after point if any, nil otherwise "
  (interactive "P\np")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward "^[:blank:]")
      (thatpt-beginning 'blank arg ispec))))

;;;###autoload
(defun blank-afpt-end-position (&optional arg ispec) 
  "Returns end position of blank after point if any, nil otherwise "
  (interactive "P\np")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward "^[:blank:]")
      (thatpt-end 'blank arg ispec))))

;;;###autoload
(defun length-of-blank-afpt (&optional arg ispec) 
  "Returns end position of blank after point if any, nil otherwise "
  (interactive "P\np")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward "^[:blank:]")
      (thatpt-length 'blank arg ispec))))

;;;###autoload
(defun copy-blank-afpt (&optional arg ispec) 
  "Returns a copy of blank after point if any, nil otherwise "
  (interactive "P\np")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward "^[:blank:]")
      (thatpt-copy 'blank arg ispec))))

;;;###autoload
(defun separate-blank-afpt (&optional arg ispec) 
  "Returns a copy of blank after point if any, nil otherwise "
  (interactive "P\np")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward "^[:blank:]")
      (thatpt-separate 'blank arg ispec))))

;;;###autoload
(defun comment-blank-afpt (&optional arg ispec) 
  "Returns a copy of blank after point if any, nil otherwise "
  (interactive "P\np")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward "^[:blank:]")
      (thatpt-comment 'blank arg ispec))))

;;;###autoload
(defun doublequote-blank-afpt (&optional arg ispec) 
  "Doublequotes blank after point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'blank 'doublequote arg ispec))

;;;###autoload
(defun singlequote-blank-afpt (&optional arg ispec) 
  "Singlequotes blank after point if any, does nothing otherwise " 
  (interactive "P\np")
  (thatpt-delim 'blank 'singlequote arg ispec))

;;;###autoload
(defun parenthese-blank-afpt (&optional arg ispec) 
  "Parentizes blank after point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'blank 'parentize arg ispec))

;;;###autoload
(defun brace-blank-afpt (&optional arg ispec) 
  "Braces blank after point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'blank 'brace arg ispec))

;;;###autoload
(defun bracket-blank-afpt (&optional arg ispec) 
  "Brackets blank after point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'blank 'bracket arg ispec))

;;;###autoload
(defun mark-blank-afpt ()
  "Marks blank after point if any, does nothing otherwise "
  (interactive "*")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward "^[:blank:]")
      (thatpt-mark 'blank))))

;;;###autoload
(defun forward-blank-afpt (&optional arg ispec) 
  "Moves forward over blank after point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-forward 'blank arg ispec))


;;;###autoload
(defun cntrl-afpt (&optional arg ispec) 
  "Returns cntrl after point if any, nil otherwise"
  (interactive "P\np")
  (or arg (setq arg 1)) 
  (save-excursion
    (thatpt 'cntrl arg ispec)))

;;;###autoload
(defun bounds-of-cntrl-afpt (&optional arg ispec) 
  "Returns border of cntrl after point if any, nil otherwise "
  (interactive "P\np")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward "^[:cntrl:]")
      (let ((cntrl (thatpt-bounds 'cntrl arg ispec)))
	(when ispec (message "   %s" cntrl))
	cntrl))))

;;;###autoload
(defun cntrl-afpt-beginning-position (&optional arg ispec) 
  "Returns beginning of cntrl after point if any, nil otherwise "
  (interactive "P\np")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward "^[:cntrl:]")
      (thatpt-beginning 'cntrl arg ispec))))

;;;###autoload
(defun cntrl-afpt-end-position (&optional arg ispec) 
  "Returns end position of cntrl after point if any, nil otherwise "
  (interactive "P\np")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward "^[:cntrl:]")
      (thatpt-end 'cntrl arg ispec))))

;;;###autoload
(defun length-of-cntrl-afpt (&optional arg ispec) 
  "Returns end position of cntrl after point if any, nil otherwise "
  (interactive "P\np")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward "^[:cntrl:]")
      (thatpt-length 'cntrl arg ispec))))

;;;###autoload
(defun copy-cntrl-afpt (&optional arg ispec) 
  "Returns a copy of cntrl after point if any, nil otherwise "
  (interactive "P\np")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward "^[:cntrl:]")
      (thatpt-copy 'cntrl arg ispec))))

;;;###autoload
(defun separate-cntrl-afpt (&optional arg ispec) 
  "Returns a copy of cntrl after point if any, nil otherwise "
  (interactive "P\np")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward "^[:cntrl:]")
      (thatpt-separate 'cntrl arg ispec))))

;;;###autoload
(defun comment-cntrl-afpt (&optional arg ispec) 
  "Returns a copy of cntrl after point if any, nil otherwise "
  (interactive "P\np")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward "^[:cntrl:]")
      (thatpt-comment 'cntrl arg ispec))))

;;;###autoload
(defun doublequote-cntrl-afpt (&optional arg ispec) 
  "Doublequotes cntrl after point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'cntrl 'doublequote arg ispec))

;;;###autoload
(defun singlequote-cntrl-afpt (&optional arg ispec) 
  "Singlequotes cntrl after point if any, does nothing otherwise " 
  (interactive "P\np")
  (thatpt-delim 'cntrl 'singlequote arg ispec))

;;;###autoload
(defun parenthese-cntrl-afpt (&optional arg ispec) 
  "Parentizes cntrl after point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'cntrl 'parentize arg ispec))

;;;###autoload
(defun brace-cntrl-afpt (&optional arg ispec) 
  "Braces cntrl after point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'cntrl 'brace arg ispec))

;;;###autoload
(defun bracket-cntrl-afpt (&optional arg ispec) 
  "Brackets cntrl after point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'cntrl 'bracket arg ispec))

;;;###autoload
(defun mark-cntrl-afpt ()
  "Marks cntrl after point if any, does nothing otherwise "
  (interactive "*")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward "^[:cntrl:]")
      (thatpt-mark 'cntrl))))

;;;###autoload
(defun forward-cntrl-afpt (&optional arg ispec) 
  "Moves forward over cntrl after point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-forward 'cntrl arg ispec))


;;;###autoload
(defun csv-afpt (&optional arg ispec) 
  "Returns csv after point if any, nil otherwise"
  (interactive "P\np")
  (or arg (setq arg 1)) 
  (save-excursion
    (thatpt 'csv arg ispec)))

;;;###autoload
(defun bounds-of-csv-afpt (&optional arg ispec) 
  "Returns border of csv after point if any, nil otherwise "
  (interactive "P\np")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward " \t\n\r\f")
      (let ((csv (thatpt-bounds 'csv arg ispec)))
	(when ispec (message "   %s" csv))
	csv))))

;;;###autoload
(defun csv-afpt-beginning-position (&optional arg ispec) 
  "Returns beginning of csv after point if any, nil otherwise "
  (interactive "P\np")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward " \t\n\r\f")
      (thatpt-beginning 'csv arg ispec))))

;;;###autoload
(defun csv-afpt-end-position (&optional arg ispec) 
  "Returns end position of csv after point if any, nil otherwise "
  (interactive "P\np")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward " \t\n\r\f")
      (thatpt-end 'csv arg ispec))))

;;;###autoload
(defun length-of-csv-afpt (&optional arg ispec) 
  "Returns end position of csv after point if any, nil otherwise "
  (interactive "P\np")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward " \t\n\r\f")
      (thatpt-length 'csv arg ispec))))

;;;###autoload
(defun copy-csv-afpt (&optional arg ispec) 
  "Returns a copy of csv after point if any, nil otherwise "
  (interactive "P\np")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward " \t\n\r\f")
      (thatpt-copy 'csv arg ispec))))

;;;###autoload
(defun separate-csv-afpt (&optional arg ispec) 
  "Returns a copy of csv after point if any, nil otherwise "
  (interactive "P\np")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward " \t\n\r\f")
      (thatpt-separate 'csv arg ispec))))

;;;###autoload
(defun comment-csv-afpt (&optional arg ispec) 
  "Returns a copy of csv after point if any, nil otherwise "
  (interactive "P\np")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward " \t\n\r\f")
      (thatpt-comment 'csv arg ispec))))

;;;###autoload
(defun doublequote-csv-afpt (&optional arg ispec) 
  "Doublequotes csv after point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'csv 'doublequote arg ispec))

;;;###autoload
(defun singlequote-csv-afpt (&optional arg ispec) 
  "Singlequotes csv after point if any, does nothing otherwise " 
  (interactive "P\np")
  (thatpt-delim 'csv 'singlequote arg ispec))

;;;###autoload
(defun parenthese-csv-afpt (&optional arg ispec) 
  "Parentizes csv after point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'csv 'parentize arg ispec))

;;;###autoload
(defun brace-csv-afpt (&optional arg ispec) 
  "Braces csv after point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'csv 'brace arg ispec))

;;;###autoload
(defun bracket-csv-afpt (&optional arg ispec) 
  "Brackets csv after point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'csv 'bracket arg ispec))

;;;###autoload
(defun mark-csv-afpt ()
  "Marks csv after point if any, does nothing otherwise "
  (interactive "*")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward " \t\n\r\f")
      (thatpt-mark 'csv))))

;;;###autoload
(defun forward-csv-afpt (&optional arg ispec) 
  "Moves forward over csv after point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-forward 'csv arg ispec))


;;;###autoload
(defun date-afpt (&optional arg ispec) 
  "Returns date after point if any, nil otherwise"
  (interactive "P\np")
  (or arg (setq arg 1)) 
  (save-excursion
    (thatpt 'date arg ispec)))

;;;###autoload
(defun bounds-of-date-afpt (&optional arg ispec) 
  "Returns border of date after point if any, nil otherwise "
  (interactive "P\np")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward " \t\n\r\f")
      (let ((date (thatpt-bounds 'date arg ispec)))
	(when ispec (message "   %s" date))
	date))))

;;;###autoload
(defun date-afpt-beginning-position (&optional arg ispec) 
  "Returns beginning of date after point if any, nil otherwise "
  (interactive "P\np")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward " \t\n\r\f")
      (thatpt-beginning 'date arg ispec))))

;;;###autoload
(defun date-afpt-end-position (&optional arg ispec) 
  "Returns end position of date after point if any, nil otherwise "
  (interactive "P\np")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward " \t\n\r\f")
      (thatpt-end 'date arg ispec))))

;;;###autoload
(defun length-of-date-afpt (&optional arg ispec) 
  "Returns end position of date after point if any, nil otherwise "
  (interactive "P\np")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward " \t\n\r\f")
      (thatpt-length 'date arg ispec))))

;;;###autoload
(defun copy-date-afpt (&optional arg ispec) 
  "Returns a copy of date after point if any, nil otherwise "
  (interactive "P\np")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward " \t\n\r\f")
      (thatpt-copy 'date arg ispec))))

;;;###autoload
(defun separate-date-afpt (&optional arg ispec) 
  "Returns a copy of date after point if any, nil otherwise "
  (interactive "P\np")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward " \t\n\r\f")
      (thatpt-separate 'date arg ispec))))

;;;###autoload
(defun comment-date-afpt (&optional arg ispec) 
  "Returns a copy of date after point if any, nil otherwise "
  (interactive "P\np")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward " \t\n\r\f")
      (thatpt-comment 'date arg ispec))))

;;;###autoload
(defun doublequote-date-afpt (&optional arg ispec) 
  "Doublequotes date after point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'date 'doublequote arg ispec))

;;;###autoload
(defun singlequote-date-afpt (&optional arg ispec) 
  "Singlequotes date after point if any, does nothing otherwise " 
  (interactive "P\np")
  (thatpt-delim 'date 'singlequote arg ispec))

;;;###autoload
(defun parenthese-date-afpt (&optional arg ispec) 
  "Parentizes date after point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'date 'parentize arg ispec))

;;;###autoload
(defun brace-date-afpt (&optional arg ispec) 
  "Braces date after point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'date 'brace arg ispec))

;;;###autoload
(defun bracket-date-afpt (&optional arg ispec) 
  "Brackets date after point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'date 'bracket arg ispec))

;;;###autoload
(defun mark-date-afpt ()
  "Marks date after point if any, does nothing otherwise "
  (interactive "*")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward " \t\n\r\f")
      (thatpt-mark 'date))))

;;;###autoload
(defun forward-date-afpt (&optional arg ispec) 
  "Moves forward over date after point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-forward 'date arg ispec))


;;;###autoload
(defun defun-afpt (&optional arg ispec) 
  "Returns defun after point if any, nil otherwise"
  (interactive "P\np")
  (or arg (setq arg 1)) 
  (save-excursion
    (thatpt 'defun arg ispec)))

;;;###autoload
(defun bounds-of-defun-afpt (&optional arg ispec) 
  "Returns border of defun after point if any, nil otherwise "
  (interactive "P\np")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward " \t\n\r\f")
      (let ((defun (thatpt-bounds 'defun arg ispec)))
	(when ispec (message "   %s" defun))
	defun))))

;;;###autoload
(defun defun-afpt-beginning-position (&optional arg ispec) 
  "Returns beginning of defun after point if any, nil otherwise "
  (interactive "P\np")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward " \t\n\r\f")
      (thatpt-beginning 'defun arg ispec))))

;;;###autoload
(defun defun-afpt-end-position (&optional arg ispec) 
  "Returns end position of defun after point if any, nil otherwise "
  (interactive "P\np")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward " \t\n\r\f")
      (thatpt-end 'defun arg ispec))))

;;;###autoload
(defun length-of-defun-afpt (&optional arg ispec) 
  "Returns end position of defun after point if any, nil otherwise "
  (interactive "P\np")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward " \t\n\r\f")
      (thatpt-length 'defun arg ispec))))

;;;###autoload
(defun copy-defun-afpt (&optional arg ispec) 
  "Returns a copy of defun after point if any, nil otherwise "
  (interactive "P\np")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward " \t\n\r\f")
      (thatpt-copy 'defun arg ispec))))

;;;###autoload
(defun separate-defun-afpt (&optional arg ispec) 
  "Returns a copy of defun after point if any, nil otherwise "
  (interactive "P\np")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward " \t\n\r\f")
      (thatpt-separate 'defun arg ispec))))

;;;###autoload
(defun comment-defun-afpt (&optional arg ispec) 
  "Returns a copy of defun after point if any, nil otherwise "
  (interactive "P\np")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward " \t\n\r\f")
      (thatpt-comment 'defun arg ispec))))

;;;###autoload
(defun doublequote-defun-afpt (&optional arg ispec) 
  "Doublequotes defun after point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'defun 'doublequote arg ispec))

;;;###autoload
(defun singlequote-defun-afpt (&optional arg ispec) 
  "Singlequotes defun after point if any, does nothing otherwise " 
  (interactive "P\np")
  (thatpt-delim 'defun 'singlequote arg ispec))

;;;###autoload
(defun parenthese-defun-afpt (&optional arg ispec) 
  "Parentizes defun after point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'defun 'parentize arg ispec))

;;;###autoload
(defun brace-defun-afpt (&optional arg ispec) 
  "Braces defun after point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'defun 'brace arg ispec))

;;;###autoload
(defun bracket-defun-afpt (&optional arg ispec) 
  "Brackets defun after point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'defun 'bracket arg ispec))

;;;###autoload
(defun mark-defun-afpt ()
  "Marks defun after point if any, does nothing otherwise "
  (interactive "*")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward " \t\n\r\f")
      (thatpt-mark 'defun))))

;;;###autoload
(defun forward-defun-afpt (&optional arg ispec) 
  "Moves forward over defun after point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-forward 'defun arg ispec))


;;;###autoload
(defun delimited-afpt (&optional arg ispec) 
  "Returns delimited after point if any, nil otherwise"
  (interactive "P\np")
  (or arg (setq arg 1)) 
  (save-excursion
    (thatpt 'delimited arg ispec)))

;;;###autoload
(defun bounds-of-delimited-afpt (&optional arg ispec) 
  "Returns border of delimited after point if any, nil otherwise "
  (interactive "P\np")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward " \t\n\r\f")
      (let ((delimited (thatpt-bounds 'delimited arg ispec)))
	(when ispec (message "   %s" delimited))
	delimited))))

;;;###autoload
(defun delimited-afpt-beginning-position (&optional arg ispec) 
  "Returns beginning of delimited after point if any, nil otherwise "
  (interactive "P\np")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward " \t\n\r\f")
      (thatpt-beginning 'delimited arg ispec))))

;;;###autoload
(defun delimited-afpt-end-position (&optional arg ispec) 
  "Returns end position of delimited after point if any, nil otherwise "
  (interactive "P\np")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward " \t\n\r\f")
      (thatpt-end 'delimited arg ispec))))

;;;###autoload
(defun length-of-delimited-afpt (&optional arg ispec) 
  "Returns end position of delimited after point if any, nil otherwise "
  (interactive "P\np")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward " \t\n\r\f")
      (thatpt-length 'delimited arg ispec))))

;;;###autoload
(defun copy-delimited-afpt (&optional arg ispec) 
  "Returns a copy of delimited after point if any, nil otherwise "
  (interactive "P\np")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward " \t\n\r\f")
      (thatpt-copy 'delimited arg ispec))))

;;;###autoload
(defun separate-delimited-afpt (&optional arg ispec) 
  "Returns a copy of delimited after point if any, nil otherwise "
  (interactive "P\np")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward " \t\n\r\f")
      (thatpt-separate 'delimited arg ispec))))

;;;###autoload
(defun comment-delimited-afpt (&optional arg ispec) 
  "Returns a copy of delimited after point if any, nil otherwise "
  (interactive "P\np")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward " \t\n\r\f")
      (thatpt-comment 'delimited arg ispec))))

;;;###autoload
(defun doublequote-delimited-afpt (&optional arg ispec) 
  "Doublequotes delimited after point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'delimited 'doublequote arg ispec))

;;;###autoload
(defun singlequote-delimited-afpt (&optional arg ispec) 
  "Singlequotes delimited after point if any, does nothing otherwise " 
  (interactive "P\np")
  (thatpt-delim 'delimited 'singlequote arg ispec))

;;;###autoload
(defun parenthese-delimited-afpt (&optional arg ispec) 
  "Parentizes delimited after point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'delimited 'parentize arg ispec))

;;;###autoload
(defun brace-delimited-afpt (&optional arg ispec) 
  "Braces delimited after point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'delimited 'brace arg ispec))

;;;###autoload
(defun bracket-delimited-afpt (&optional arg ispec) 
  "Brackets delimited after point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'delimited 'bracket arg ispec))

;;;###autoload
(defun mark-delimited-afpt ()
  "Marks delimited after point if any, does nothing otherwise "
  (interactive "*")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward " \t\n\r\f")
      (thatpt-mark 'delimited))))

;;;###autoload
(defun forward-delimited-afpt (&optional arg ispec) 
  "Moves forward over delimited after point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-forward 'delimited arg ispec))


;;;###autoload
(defun digit-afpt (&optional arg ispec) 
  "Returns digit after point if any, nil otherwise"
  (interactive "P\np")
  (or arg (setq arg 1)) 
  (save-excursion
    (thatpt 'digit arg ispec)))

;;;###autoload
(defun bounds-of-digit-afpt (&optional arg ispec) 
  "Returns border of digit after point if any, nil otherwise "
  (interactive "P\np")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward "^[:digit:]")
      (let ((digit (thatpt-bounds 'digit arg ispec)))
	(when ispec (message "   %s" digit))
	digit))))

;;;###autoload
(defun digit-afpt-beginning-position (&optional arg ispec) 
  "Returns beginning of digit after point if any, nil otherwise "
  (interactive "P\np")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward "^[:digit:]")
      (thatpt-beginning 'digit arg ispec))))

;;;###autoload
(defun digit-afpt-end-position (&optional arg ispec) 
  "Returns end position of digit after point if any, nil otherwise "
  (interactive "P\np")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward "^[:digit:]")
      (thatpt-end 'digit arg ispec))))

;;;###autoload
(defun length-of-digit-afpt (&optional arg ispec) 
  "Returns end position of digit after point if any, nil otherwise "
  (interactive "P\np")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward "^[:digit:]")
      (thatpt-length 'digit arg ispec))))

;;;###autoload
(defun copy-digit-afpt (&optional arg ispec) 
  "Returns a copy of digit after point if any, nil otherwise "
  (interactive "P\np")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward "^[:digit:]")
      (thatpt-copy 'digit arg ispec))))

;;;###autoload
(defun separate-digit-afpt (&optional arg ispec) 
  "Returns a copy of digit after point if any, nil otherwise "
  (interactive "P\np")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward "^[:digit:]")
      (thatpt-separate 'digit arg ispec))))

;;;###autoload
(defun comment-digit-afpt (&optional arg ispec) 
  "Returns a copy of digit after point if any, nil otherwise "
  (interactive "P\np")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward "^[:digit:]")
      (thatpt-comment 'digit arg ispec))))

;;;###autoload
(defun doublequote-digit-afpt (&optional arg ispec) 
  "Doublequotes digit after point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'digit 'doublequote arg ispec))

;;;###autoload
(defun singlequote-digit-afpt (&optional arg ispec) 
  "Singlequotes digit after point if any, does nothing otherwise " 
  (interactive "P\np")
  (thatpt-delim 'digit 'singlequote arg ispec))

;;;###autoload
(defun parenthese-digit-afpt (&optional arg ispec) 
  "Parentizes digit after point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'digit 'parentize arg ispec))

;;;###autoload
(defun brace-digit-afpt (&optional arg ispec) 
  "Braces digit after point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'digit 'brace arg ispec))

;;;###autoload
(defun bracket-digit-afpt (&optional arg ispec) 
  "Brackets digit after point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'digit 'bracket arg ispec))

;;;###autoload
(defun mark-digit-afpt ()
  "Marks digit after point if any, does nothing otherwise "
  (interactive "*")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward "^[:digit:]")
      (thatpt-mark 'digit))))

;;;###autoload
(defun forward-digit-afpt (&optional arg ispec) 
  "Moves forward over digit after point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-forward 'digit arg ispec))


;;;###autoload
(defun email-afpt (&optional arg ispec) 
  "Returns email after point if any, nil otherwise"
  (interactive "P\np")
  (or arg (setq arg 1)) 
  (save-excursion
    (thatpt 'email arg ispec)))

;;;###autoload
(defun bounds-of-email-afpt (&optional arg ispec) 
  "Returns border of email after point if any, nil otherwise "
  (interactive "P\np")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward " \t\n\r\f")
      (let ((email (thatpt-bounds 'email arg ispec)))
	(when ispec (message "   %s" email))
	email))))

;;;###autoload
(defun email-afpt-beginning-position (&optional arg ispec) 
  "Returns beginning of email after point if any, nil otherwise "
  (interactive "P\np")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward " \t\n\r\f")
      (thatpt-beginning 'email arg ispec))))

;;;###autoload
(defun email-afpt-end-position (&optional arg ispec) 
  "Returns end position of email after point if any, nil otherwise "
  (interactive "P\np")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward " \t\n\r\f")
      (thatpt-end 'email arg ispec))))

;;;###autoload
(defun length-of-email-afpt (&optional arg ispec) 
  "Returns end position of email after point if any, nil otherwise "
  (interactive "P\np")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward " \t\n\r\f")
      (thatpt-length 'email arg ispec))))

;;;###autoload
(defun copy-email-afpt (&optional arg ispec) 
  "Returns a copy of email after point if any, nil otherwise "
  (interactive "P\np")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward " \t\n\r\f")
      (thatpt-copy 'email arg ispec))))

;;;###autoload
(defun separate-email-afpt (&optional arg ispec) 
  "Returns a copy of email after point if any, nil otherwise "
  (interactive "P\np")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward " \t\n\r\f")
      (thatpt-separate 'email arg ispec))))

;;;###autoload
(defun comment-email-afpt (&optional arg ispec) 
  "Returns a copy of email after point if any, nil otherwise "
  (interactive "P\np")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward " \t\n\r\f")
      (thatpt-comment 'email arg ispec))))

;;;###autoload
(defun doublequote-email-afpt (&optional arg ispec) 
  "Doublequotes email after point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'email 'doublequote arg ispec))

;;;###autoload
(defun singlequote-email-afpt (&optional arg ispec) 
  "Singlequotes email after point if any, does nothing otherwise " 
  (interactive "P\np")
  (thatpt-delim 'email 'singlequote arg ispec))

;;;###autoload
(defun parenthese-email-afpt (&optional arg ispec) 
  "Parentizes email after point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'email 'parentize arg ispec))

;;;###autoload
(defun brace-email-afpt (&optional arg ispec) 
  "Braces email after point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'email 'brace arg ispec))

;;;###autoload
(defun bracket-email-afpt (&optional arg ispec) 
  "Brackets email after point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'email 'bracket arg ispec))

;;;###autoload
(defun mark-email-afpt ()
  "Marks email after point if any, does nothing otherwise "
  (interactive "*")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward " \t\n\r\f")
      (thatpt-mark 'email))))

;;;###autoload
(defun forward-email-afpt (&optional arg ispec) 
  "Moves forward over email after point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-forward 'email arg ispec))


;;;###autoload
(defun filename-afpt (&optional arg ispec) 
  "Returns filename after point if any, nil otherwise"
  (interactive "P\np")
  (or arg (setq arg 1)) 
  (save-excursion
    (thatpt 'filename arg ispec)))

;;;###autoload
(defun bounds-of-filename-afpt (&optional arg ispec) 
  "Returns border of filename after point if any, nil otherwise "
  (interactive "P\np")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward " \t\n\r\f")
      (let ((filename (thatpt-bounds 'filename arg ispec)))
	(when ispec (message "   %s" filename))
	filename))))

;;;###autoload
(defun filename-afpt-beginning-position (&optional arg ispec) 
  "Returns beginning of filename after point if any, nil otherwise "
  (interactive "P\np")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward " \t\n\r\f")
      (thatpt-beginning 'filename arg ispec))))

;;;###autoload
(defun filename-afpt-end-position (&optional arg ispec) 
  "Returns end position of filename after point if any, nil otherwise "
  (interactive "P\np")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward " \t\n\r\f")
      (thatpt-end 'filename arg ispec))))

;;;###autoload
(defun length-of-filename-afpt (&optional arg ispec) 
  "Returns end position of filename after point if any, nil otherwise "
  (interactive "P\np")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward " \t\n\r\f")
      (thatpt-length 'filename arg ispec))))

;;;###autoload
(defun copy-filename-afpt (&optional arg ispec) 
  "Returns a copy of filename after point if any, nil otherwise "
  (interactive "P\np")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward " \t\n\r\f")
      (thatpt-copy 'filename arg ispec))))

;;;###autoload
(defun separate-filename-afpt (&optional arg ispec) 
  "Returns a copy of filename after point if any, nil otherwise "
  (interactive "P\np")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward " \t\n\r\f")
      (thatpt-separate 'filename arg ispec))))

;;;###autoload
(defun comment-filename-afpt (&optional arg ispec) 
  "Returns a copy of filename after point if any, nil otherwise "
  (interactive "P\np")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward " \t\n\r\f")
      (thatpt-comment 'filename arg ispec))))

;;;###autoload
(defun doublequote-filename-afpt (&optional arg ispec) 
  "Doublequotes filename after point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'filename 'doublequote arg ispec))

;;;###autoload
(defun singlequote-filename-afpt (&optional arg ispec) 
  "Singlequotes filename after point if any, does nothing otherwise " 
  (interactive "P\np")
  (thatpt-delim 'filename 'singlequote arg ispec))

;;;###autoload
(defun parenthese-filename-afpt (&optional arg ispec) 
  "Parentizes filename after point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'filename 'parentize arg ispec))

;;;###autoload
(defun brace-filename-afpt (&optional arg ispec) 
  "Braces filename after point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'filename 'brace arg ispec))

;;;###autoload
(defun bracket-filename-afpt (&optional arg ispec) 
  "Brackets filename after point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'filename 'bracket arg ispec))

;;;###autoload
(defun mark-filename-afpt ()
  "Marks filename after point if any, does nothing otherwise "
  (interactive "*")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward " \t\n\r\f")
      (thatpt-mark 'filename))))

;;;###autoload
(defun forward-filename-afpt (&optional arg ispec) 
  "Moves forward over filename after point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-forward 'filename arg ispec))


;;;###autoload
(defun float-afpt (&optional arg ispec) 
  "Returns float after point if any, nil otherwise"
  (interactive "P\np")
  (or arg (setq arg 1)) 
  (save-excursion
    (thatpt 'float arg ispec)))

;;;###autoload
(defun bounds-of-float-afpt (&optional arg ispec) 
  "Returns border of float after point if any, nil otherwise "
  (interactive "P\np")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward " \t\n\r\f")
      (let ((float (thatpt-bounds 'float arg ispec)))
	(when ispec (message "   %s" float))
	float))))

;;;###autoload
(defun float-afpt-beginning-position (&optional arg ispec) 
  "Returns beginning of float after point if any, nil otherwise "
  (interactive "P\np")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward " \t\n\r\f")
      (thatpt-beginning 'float arg ispec))))

;;;###autoload
(defun float-afpt-end-position (&optional arg ispec) 
  "Returns end position of float after point if any, nil otherwise "
  (interactive "P\np")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward " \t\n\r\f")
      (thatpt-end 'float arg ispec))))

;;;###autoload
(defun length-of-float-afpt (&optional arg ispec) 
  "Returns end position of float after point if any, nil otherwise "
  (interactive "P\np")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward " \t\n\r\f")
      (thatpt-length 'float arg ispec))))

;;;###autoload
(defun copy-float-afpt (&optional arg ispec) 
  "Returns a copy of float after point if any, nil otherwise "
  (interactive "P\np")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward " \t\n\r\f")
      (thatpt-copy 'float arg ispec))))

;;;###autoload
(defun separate-float-afpt (&optional arg ispec) 
  "Returns a copy of float after point if any, nil otherwise "
  (interactive "P\np")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward " \t\n\r\f")
      (thatpt-separate 'float arg ispec))))

;;;###autoload
(defun comment-float-afpt (&optional arg ispec) 
  "Returns a copy of float after point if any, nil otherwise "
  (interactive "P\np")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward " \t\n\r\f")
      (thatpt-comment 'float arg ispec))))

;;;###autoload
(defun doublequote-float-afpt (&optional arg ispec) 
  "Doublequotes float after point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'float 'doublequote arg ispec))

;;;###autoload
(defun singlequote-float-afpt (&optional arg ispec) 
  "Singlequotes float after point if any, does nothing otherwise " 
  (interactive "P\np")
  (thatpt-delim 'float 'singlequote arg ispec))

;;;###autoload
(defun parenthese-float-afpt (&optional arg ispec) 
  "Parentizes float after point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'float 'parentize arg ispec))

;;;###autoload
(defun brace-float-afpt (&optional arg ispec) 
  "Braces float after point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'float 'brace arg ispec))

;;;###autoload
(defun bracket-float-afpt (&optional arg ispec) 
  "Brackets float after point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'float 'bracket arg ispec))

;;;###autoload
(defun mark-float-afpt ()
  "Marks float after point if any, does nothing otherwise "
  (interactive "*")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward " \t\n\r\f")
      (thatpt-mark 'float))))

;;;###autoload
(defun forward-float-afpt (&optional arg ispec) 
  "Moves forward over float after point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-forward 'float arg ispec))


;;;###autoload
(defun graph-afpt (&optional arg ispec) 
  "Returns graph after point if any, nil otherwise"
  (interactive "P\np")
  (or arg (setq arg 1)) 
  (save-excursion
    (thatpt 'graph arg ispec)))

;;;###autoload
(defun bounds-of-graph-afpt (&optional arg ispec) 
  "Returns border of graph after point if any, nil otherwise "
  (interactive "P\np")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward "^[:graph:]")
      (let ((graph (thatpt-bounds 'graph arg ispec)))
	(when ispec (message "   %s" graph))
	graph))))

;;;###autoload
(defun graph-afpt-beginning-position (&optional arg ispec) 
  "Returns beginning of graph after point if any, nil otherwise "
  (interactive "P\np")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward "^[:graph:]")
      (thatpt-beginning 'graph arg ispec))))

;;;###autoload
(defun graph-afpt-end-position (&optional arg ispec) 
  "Returns end position of graph after point if any, nil otherwise "
  (interactive "P\np")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward "^[:graph:]")
      (thatpt-end 'graph arg ispec))))

;;;###autoload
(defun length-of-graph-afpt (&optional arg ispec) 
  "Returns end position of graph after point if any, nil otherwise "
  (interactive "P\np")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward "^[:graph:]")
      (thatpt-length 'graph arg ispec))))

;;;###autoload
(defun copy-graph-afpt (&optional arg ispec) 
  "Returns a copy of graph after point if any, nil otherwise "
  (interactive "P\np")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward "^[:graph:]")
      (thatpt-copy 'graph arg ispec))))

;;;###autoload
(defun separate-graph-afpt (&optional arg ispec) 
  "Returns a copy of graph after point if any, nil otherwise "
  (interactive "P\np")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward "^[:graph:]")
      (thatpt-separate 'graph arg ispec))))

;;;###autoload
(defun comment-graph-afpt (&optional arg ispec) 
  "Returns a copy of graph after point if any, nil otherwise "
  (interactive "P\np")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward "^[:graph:]")
      (thatpt-comment 'graph arg ispec))))

;;;###autoload
(defun doublequote-graph-afpt (&optional arg ispec) 
  "Doublequotes graph after point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'graph 'doublequote arg ispec))

;;;###autoload
(defun singlequote-graph-afpt (&optional arg ispec) 
  "Singlequotes graph after point if any, does nothing otherwise " 
  (interactive "P\np")
  (thatpt-delim 'graph 'singlequote arg ispec))

;;;###autoload
(defun parenthese-graph-afpt (&optional arg ispec) 
  "Parentizes graph after point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'graph 'parentize arg ispec))

;;;###autoload
(defun brace-graph-afpt (&optional arg ispec) 
  "Braces graph after point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'graph 'brace arg ispec))

;;;###autoload
(defun bracket-graph-afpt (&optional arg ispec) 
  "Brackets graph after point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'graph 'bracket arg ispec))

;;;###autoload
(defun mark-graph-afpt ()
  "Marks graph after point if any, does nothing otherwise "
  (interactive "*")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward "^[:graph:]")
      (thatpt-mark 'graph))))

;;;###autoload
(defun forward-graph-afpt (&optional arg ispec) 
  "Moves forward over graph after point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-forward 'graph arg ispec))


;;;###autoload
(defun isbn-afpt (&optional arg ispec) 
  "Returns isbn after point if any, nil otherwise"
  (interactive "P\np")
  (or arg (setq arg 1)) 
  (save-excursion
    (thatpt 'isbn arg ispec)))

;;;###autoload
(defun bounds-of-isbn-afpt (&optional arg ispec) 
  "Returns border of isbn after point if any, nil otherwise "
  (interactive "P\np")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward " \t\n\r\f")
      (let ((isbn (thatpt-bounds 'isbn arg ispec)))
	(when ispec (message "   %s" isbn))
	isbn))))

;;;###autoload
(defun isbn-afpt-beginning-position (&optional arg ispec) 
  "Returns beginning of isbn after point if any, nil otherwise "
  (interactive "P\np")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward " \t\n\r\f")
      (thatpt-beginning 'isbn arg ispec))))

;;;###autoload
(defun isbn-afpt-end-position (&optional arg ispec) 
  "Returns end position of isbn after point if any, nil otherwise "
  (interactive "P\np")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward " \t\n\r\f")
      (thatpt-end 'isbn arg ispec))))

;;;###autoload
(defun length-of-isbn-afpt (&optional arg ispec) 
  "Returns end position of isbn after point if any, nil otherwise "
  (interactive "P\np")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward " \t\n\r\f")
      (thatpt-length 'isbn arg ispec))))

;;;###autoload
(defun copy-isbn-afpt (&optional arg ispec) 
  "Returns a copy of isbn after point if any, nil otherwise "
  (interactive "P\np")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward " \t\n\r\f")
      (thatpt-copy 'isbn arg ispec))))

;;;###autoload
(defun separate-isbn-afpt (&optional arg ispec) 
  "Returns a copy of isbn after point if any, nil otherwise "
  (interactive "P\np")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward " \t\n\r\f")
      (thatpt-separate 'isbn arg ispec))))

;;;###autoload
(defun comment-isbn-afpt (&optional arg ispec) 
  "Returns a copy of isbn after point if any, nil otherwise "
  (interactive "P\np")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward " \t\n\r\f")
      (thatpt-comment 'isbn arg ispec))))

;;;###autoload
(defun doublequote-isbn-afpt (&optional arg ispec) 
  "Doublequotes isbn after point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'isbn 'doublequote arg ispec))

;;;###autoload
(defun singlequote-isbn-afpt (&optional arg ispec) 
  "Singlequotes isbn after point if any, does nothing otherwise " 
  (interactive "P\np")
  (thatpt-delim 'isbn 'singlequote arg ispec))

;;;###autoload
(defun parenthese-isbn-afpt (&optional arg ispec) 
  "Parentizes isbn after point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'isbn 'parentize arg ispec))

;;;###autoload
(defun brace-isbn-afpt (&optional arg ispec) 
  "Braces isbn after point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'isbn 'brace arg ispec))

;;;###autoload
(defun bracket-isbn-afpt (&optional arg ispec) 
  "Brackets isbn after point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'isbn 'bracket arg ispec))

;;;###autoload
(defun mark-isbn-afpt ()
  "Marks isbn after point if any, does nothing otherwise "
  (interactive "*")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward " \t\n\r\f")
      (thatpt-mark 'isbn))))

;;;###autoload
(defun forward-isbn-afpt (&optional arg ispec) 
  "Moves forward over isbn after point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-forward 'isbn arg ispec))


;;;###autoload
(defun line-afpt (&optional arg ispec) 
  "Returns line after point if any, nil otherwise"
  (interactive "P\np")
  (or arg (setq arg 1)) 
  (save-excursion
    (thatpt 'line arg ispec)))

;;;###autoload
(defun bounds-of-line-afpt (&optional arg ispec) 
  "Returns border of line after point if any, nil otherwise "
  (interactive "P\np")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward " \t\n\r\f")
      (let ((line (thatpt-bounds 'line arg ispec)))
	(when ispec (message "   %s" line))
	line))))

;;;###autoload
(defun line-afpt-beginning-position (&optional arg ispec) 
  "Returns beginning of line after point if any, nil otherwise "
  (interactive "P\np")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward " \t\n\r\f")
      (thatpt-beginning 'line arg ispec))))

;;;###autoload
(defun line-afpt-end-position (&optional arg ispec) 
  "Returns end position of line after point if any, nil otherwise "
  (interactive "P\np")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward " \t\n\r\f")
      (thatpt-end 'line arg ispec))))

;;;###autoload
(defun length-of-line-afpt (&optional arg ispec) 
  "Returns end position of line after point if any, nil otherwise "
  (interactive "P\np")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward " \t\n\r\f")
      (thatpt-length 'line arg ispec))))

;;;###autoload
(defun copy-line-afpt (&optional arg ispec) 
  "Returns a copy of line after point if any, nil otherwise "
  (interactive "P\np")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward " \t\n\r\f")
      (thatpt-copy 'line arg ispec))))

;;;###autoload
(defun separate-line-afpt (&optional arg ispec) 
  "Returns a copy of line after point if any, nil otherwise "
  (interactive "P\np")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward " \t\n\r\f")
      (thatpt-separate 'line arg ispec))))

;;;###autoload
(defun comment-line-afpt (&optional arg ispec) 
  "Returns a copy of line after point if any, nil otherwise "
  (interactive "P\np")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward " \t\n\r\f")
      (thatpt-comment 'line arg ispec))))

;;;###autoload
(defun doublequote-line-afpt (&optional arg ispec) 
  "Doublequotes line after point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'line 'doublequote arg ispec))

;;;###autoload
(defun singlequote-line-afpt (&optional arg ispec) 
  "Singlequotes line after point if any, does nothing otherwise " 
  (interactive "P\np")
  (thatpt-delim 'line 'singlequote arg ispec))

;;;###autoload
(defun parenthese-line-afpt (&optional arg ispec) 
  "Parentizes line after point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'line 'parentize arg ispec))

;;;###autoload
(defun brace-line-afpt (&optional arg ispec) 
  "Braces line after point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'line 'brace arg ispec))

;;;###autoload
(defun bracket-line-afpt (&optional arg ispec) 
  "Brackets line after point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'line 'bracket arg ispec))

;;;###autoload
(defun mark-line-afpt ()
  "Marks line after point if any, does nothing otherwise "
  (interactive "*")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward " \t\n\r\f")
      (thatpt-mark 'line))))

;;;###autoload
(defun forward-line-afpt (&optional arg ispec) 
  "Moves forward over line after point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-forward 'line arg ispec))


;;;###autoload
(defun list-afpt (&optional arg ispec) 
  "Returns list after point if any, nil otherwise"
  (interactive "P\np")
  (or arg (setq arg 1)) 
  (save-excursion
    (thatpt 'list arg ispec)))

;;;###autoload
(defun bounds-of-list-afpt (&optional arg ispec) 
  "Returns border of list after point if any, nil otherwise "
  (interactive "P\np")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward " \t\n\r\f")
      (let ((list (thatpt-bounds 'list arg ispec)))
	(when ispec (message "   %s" list))
	list))))

;;;###autoload
(defun list-afpt-beginning-position (&optional arg ispec) 
  "Returns beginning of list after point if any, nil otherwise "
  (interactive "P\np")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward " \t\n\r\f")
      (thatpt-beginning 'list arg ispec))))

;;;###autoload
(defun list-afpt-end-position (&optional arg ispec) 
  "Returns end position of list after point if any, nil otherwise "
  (interactive "P\np")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward " \t\n\r\f")
      (thatpt-end 'list arg ispec))))

;;;###autoload
(defun length-of-list-afpt (&optional arg ispec) 
  "Returns end position of list after point if any, nil otherwise "
  (interactive "P\np")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward " \t\n\r\f")
      (thatpt-length 'list arg ispec))))

;;;###autoload
(defun copy-list-afpt (&optional arg ispec) 
  "Returns a copy of list after point if any, nil otherwise "
  (interactive "P\np")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward " \t\n\r\f")
      (thatpt-copy 'list arg ispec))))

;;;###autoload
(defun separate-list-afpt (&optional arg ispec) 
  "Returns a copy of list after point if any, nil otherwise "
  (interactive "P\np")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward " \t\n\r\f")
      (thatpt-separate 'list arg ispec))))

;;;###autoload
(defun comment-list-afpt (&optional arg ispec) 
  "Returns a copy of list after point if any, nil otherwise "
  (interactive "P\np")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward " \t\n\r\f")
      (thatpt-comment 'list arg ispec))))

;;;###autoload
(defun doublequote-list-afpt (&optional arg ispec) 
  "Doublequotes list after point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'list 'doublequote arg ispec))

;;;###autoload
(defun singlequote-list-afpt (&optional arg ispec) 
  "Singlequotes list after point if any, does nothing otherwise " 
  (interactive "P\np")
  (thatpt-delim 'list 'singlequote arg ispec))

;;;###autoload
(defun parenthese-list-afpt (&optional arg ispec) 
  "Parentizes list after point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'list 'parentize arg ispec))

;;;###autoload
(defun brace-list-afpt (&optional arg ispec) 
  "Braces list after point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'list 'brace arg ispec))

;;;###autoload
(defun bracket-list-afpt (&optional arg ispec) 
  "Brackets list after point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'list 'bracket arg ispec))

;;;###autoload
(defun mark-list-afpt ()
  "Marks list after point if any, does nothing otherwise "
  (interactive "*")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward " \t\n\r\f")
      (thatpt-mark 'list))))

;;;###autoload
(defun forward-list-afpt (&optional arg ispec) 
  "Moves forward over list after point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-forward 'list arg ispec))


;;;###autoload
(defun lower-afpt (&optional arg ispec) 
  "Returns lower after point if any, nil otherwise"
  (interactive "P\np")
  (or arg (setq arg 1)) 
  (save-excursion
    (thatpt 'lower arg ispec)))

;;;###autoload
(defun bounds-of-lower-afpt (&optional arg ispec) 
  "Returns border of lower after point if any, nil otherwise "
  (interactive "P\np")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward "^[:lower:]")
      (let ((lower (thatpt-bounds 'lower arg ispec)))
	(when ispec (message "   %s" lower))
	lower))))

;;;###autoload
(defun lower-afpt-beginning-position (&optional arg ispec) 
  "Returns beginning of lower after point if any, nil otherwise "
  (interactive "P\np")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward "^[:lower:]")
      (thatpt-beginning 'lower arg ispec))))

;;;###autoload
(defun lower-afpt-end-position (&optional arg ispec) 
  "Returns end position of lower after point if any, nil otherwise "
  (interactive "P\np")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward "^[:lower:]")
      (thatpt-end 'lower arg ispec))))

;;;###autoload
(defun length-of-lower-afpt (&optional arg ispec) 
  "Returns end position of lower after point if any, nil otherwise "
  (interactive "P\np")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward "^[:lower:]")
      (thatpt-length 'lower arg ispec))))

;;;###autoload
(defun copy-lower-afpt (&optional arg ispec) 
  "Returns a copy of lower after point if any, nil otherwise "
  (interactive "P\np")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward "^[:lower:]")
      (thatpt-copy 'lower arg ispec))))

;;;###autoload
(defun separate-lower-afpt (&optional arg ispec) 
  "Returns a copy of lower after point if any, nil otherwise "
  (interactive "P\np")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward "^[:lower:]")
      (thatpt-separate 'lower arg ispec))))

;;;###autoload
(defun comment-lower-afpt (&optional arg ispec) 
  "Returns a copy of lower after point if any, nil otherwise "
  (interactive "P\np")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward "^[:lower:]")
      (thatpt-comment 'lower arg ispec))))

;;;###autoload
(defun doublequote-lower-afpt (&optional arg ispec) 
  "Doublequotes lower after point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'lower 'doublequote arg ispec))

;;;###autoload
(defun singlequote-lower-afpt (&optional arg ispec) 
  "Singlequotes lower after point if any, does nothing otherwise " 
  (interactive "P\np")
  (thatpt-delim 'lower 'singlequote arg ispec))

;;;###autoload
(defun parenthese-lower-afpt (&optional arg ispec) 
  "Parentizes lower after point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'lower 'parentize arg ispec))

;;;###autoload
(defun brace-lower-afpt (&optional arg ispec) 
  "Braces lower after point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'lower 'brace arg ispec))

;;;###autoload
(defun bracket-lower-afpt (&optional arg ispec) 
  "Brackets lower after point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'lower 'bracket arg ispec))

;;;###autoload
(defun mark-lower-afpt ()
  "Marks lower after point if any, does nothing otherwise "
  (interactive "*")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward "^[:lower:]")
      (thatpt-mark 'lower))))

;;;###autoload
(defun forward-lower-afpt (&optional arg ispec) 
  "Moves forward over lower after point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-forward 'lower arg ispec))


;;;###autoload
(defun ml-text-afpt (&optional arg ispec) 
  "Returns ml-text after point if any, nil otherwise"
  (interactive "P\np")
  (or arg (setq arg 1)) 
  (save-excursion
    (thatpt 'ml-text arg ispec)))

;;;###autoload
(defun bounds-of-ml-text-afpt (&optional arg ispec) 
  "Returns border of ml-text after point if any, nil otherwise "
  (interactive "P\np")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward " \t\n\r\f")
      (let ((ml-text (thatpt-bounds 'ml-text arg ispec)))
	(when ispec (message "   %s" ml-text))
	ml-text))))

;;;###autoload
(defun ml-text-afpt-beginning-position (&optional arg ispec) 
  "Returns beginning of ml-text after point if any, nil otherwise "
  (interactive "P\np")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward " \t\n\r\f")
      (thatpt-beginning 'ml-text arg ispec))))

;;;###autoload
(defun ml-text-afpt-end-position (&optional arg ispec) 
  "Returns end position of ml-text after point if any, nil otherwise "
  (interactive "P\np")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward " \t\n\r\f")
      (thatpt-end 'ml-text arg ispec))))

;;;###autoload
(defun length-of-ml-text-afpt (&optional arg ispec) 
  "Returns end position of ml-text after point if any, nil otherwise "
  (interactive "P\np")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward " \t\n\r\f")
      (thatpt-length 'ml-text arg ispec))))

;;;###autoload
(defun copy-ml-text-afpt (&optional arg ispec) 
  "Returns a copy of ml-text after point if any, nil otherwise "
  (interactive "P\np")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward " \t\n\r\f")
      (thatpt-copy 'ml-text arg ispec))))

;;;###autoload
(defun separate-ml-text-afpt (&optional arg ispec) 
  "Returns a copy of ml-text after point if any, nil otherwise "
  (interactive "P\np")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward " \t\n\r\f")
      (thatpt-separate 'ml-text arg ispec))))

;;;###autoload
(defun comment-ml-text-afpt (&optional arg ispec) 
  "Returns a copy of ml-text after point if any, nil otherwise "
  (interactive "P\np")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward " \t\n\r\f")
      (thatpt-comment 'ml-text arg ispec))))

;;;###autoload
(defun doublequote-ml-text-afpt (&optional arg ispec) 
  "Doublequotes ml-text after point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'ml-text 'doublequote arg ispec))

;;;###autoload
(defun singlequote-ml-text-afpt (&optional arg ispec) 
  "Singlequotes ml-text after point if any, does nothing otherwise " 
  (interactive "P\np")
  (thatpt-delim 'ml-text 'singlequote arg ispec))

;;;###autoload
(defun parenthese-ml-text-afpt (&optional arg ispec) 
  "Parentizes ml-text after point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'ml-text 'parentize arg ispec))

;;;###autoload
(defun brace-ml-text-afpt (&optional arg ispec) 
  "Braces ml-text after point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'ml-text 'brace arg ispec))

;;;###autoload
(defun bracket-ml-text-afpt (&optional arg ispec) 
  "Brackets ml-text after point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'ml-text 'bracket arg ispec))

;;;###autoload
(defun mark-ml-text-afpt ()
  "Marks ml-text after point if any, does nothing otherwise "
  (interactive "*")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward " \t\n\r\f")
      (thatpt-mark 'ml-text))))

;;;###autoload
(defun forward-ml-text-afpt (&optional arg ispec) 
  "Moves forward over ml-text after point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-forward 'ml-text arg ispec))


;;;###autoload
(defun multibyte-afpt (&optional arg ispec) 
  "Returns multibyte after point if any, nil otherwise"
  (interactive "P\np")
  (or arg (setq arg 1)) 
  (save-excursion
    (thatpt 'multibyte arg ispec)))

;;;###autoload
(defun bounds-of-multibyte-afpt (&optional arg ispec) 
  "Returns border of multibyte after point if any, nil otherwise "
  (interactive "P\np")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward "^[:multibyte:]")
      (let ((multibyte (thatpt-bounds 'multibyte arg ispec)))
	(when ispec (message "   %s" multibyte))
	multibyte))))

;;;###autoload
(defun multibyte-afpt-beginning-position (&optional arg ispec) 
  "Returns beginning of multibyte after point if any, nil otherwise "
  (interactive "P\np")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward "^[:multibyte:]")
      (thatpt-beginning 'multibyte arg ispec))))

;;;###autoload
(defun multibyte-afpt-end-position (&optional arg ispec) 
  "Returns end position of multibyte after point if any, nil otherwise "
  (interactive "P\np")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward "^[:multibyte:]")
      (thatpt-end 'multibyte arg ispec))))

;;;###autoload
(defun length-of-multibyte-afpt (&optional arg ispec) 
  "Returns end position of multibyte after point if any, nil otherwise "
  (interactive "P\np")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward "^[:multibyte:]")
      (thatpt-length 'multibyte arg ispec))))

;;;###autoload
(defun copy-multibyte-afpt (&optional arg ispec) 
  "Returns a copy of multibyte after point if any, nil otherwise "
  (interactive "P\np")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward "^[:multibyte:]")
      (thatpt-copy 'multibyte arg ispec))))

;;;###autoload
(defun separate-multibyte-afpt (&optional arg ispec) 
  "Returns a copy of multibyte after point if any, nil otherwise "
  (interactive "P\np")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward "^[:multibyte:]")
      (thatpt-separate 'multibyte arg ispec))))

;;;###autoload
(defun comment-multibyte-afpt (&optional arg ispec) 
  "Returns a copy of multibyte after point if any, nil otherwise "
  (interactive "P\np")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward "^[:multibyte:]")
      (thatpt-comment 'multibyte arg ispec))))

;;;###autoload
(defun doublequote-multibyte-afpt (&optional arg ispec) 
  "Doublequotes multibyte after point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'multibyte 'doublequote arg ispec))

;;;###autoload
(defun singlequote-multibyte-afpt (&optional arg ispec) 
  "Singlequotes multibyte after point if any, does nothing otherwise " 
  (interactive "P\np")
  (thatpt-delim 'multibyte 'singlequote arg ispec))

;;;###autoload
(defun parenthese-multibyte-afpt (&optional arg ispec) 
  "Parentizes multibyte after point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'multibyte 'parentize arg ispec))

;;;###autoload
(defun brace-multibyte-afpt (&optional arg ispec) 
  "Braces multibyte after point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'multibyte 'brace arg ispec))

;;;###autoload
(defun bracket-multibyte-afpt (&optional arg ispec) 
  "Brackets multibyte after point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'multibyte 'bracket arg ispec))

;;;###autoload
(defun mark-multibyte-afpt ()
  "Marks multibyte after point if any, does nothing otherwise "
  (interactive "*")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward "^[:multibyte:]")
      (thatpt-mark 'multibyte))))

;;;###autoload
(defun forward-multibyte-afpt (&optional arg ispec) 
  "Moves forward over multibyte after point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-forward 'multibyte arg ispec))


;;;###autoload
(defun nonascii-afpt (&optional arg ispec) 
  "Returns nonascii after point if any, nil otherwise"
  (interactive "P\np")
  (or arg (setq arg 1)) 
  (save-excursion
    (thatpt 'nonascii arg ispec)))

;;;###autoload
(defun bounds-of-nonascii-afpt (&optional arg ispec) 
  "Returns border of nonascii after point if any, nil otherwise "
  (interactive "P\np")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward "^[:nonascii:]")
      (let ((nonascii (thatpt-bounds 'nonascii arg ispec)))
	(when ispec (message "   %s" nonascii))
	nonascii))))

;;;###autoload
(defun nonascii-afpt-beginning-position (&optional arg ispec) 
  "Returns beginning of nonascii after point if any, nil otherwise "
  (interactive "P\np")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward "^[:nonascii:]")
      (thatpt-beginning 'nonascii arg ispec))))

;;;###autoload
(defun nonascii-afpt-end-position (&optional arg ispec) 
  "Returns end position of nonascii after point if any, nil otherwise "
  (interactive "P\np")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward "^[:nonascii:]")
      (thatpt-end 'nonascii arg ispec))))

;;;###autoload
(defun length-of-nonascii-afpt (&optional arg ispec) 
  "Returns end position of nonascii after point if any, nil otherwise "
  (interactive "P\np")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward "^[:nonascii:]")
      (thatpt-length 'nonascii arg ispec))))

;;;###autoload
(defun copy-nonascii-afpt (&optional arg ispec) 
  "Returns a copy of nonascii after point if any, nil otherwise "
  (interactive "P\np")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward "^[:nonascii:]")
      (thatpt-copy 'nonascii arg ispec))))

;;;###autoload
(defun separate-nonascii-afpt (&optional arg ispec) 
  "Returns a copy of nonascii after point if any, nil otherwise "
  (interactive "P\np")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward "^[:nonascii:]")
      (thatpt-separate 'nonascii arg ispec))))

;;;###autoload
(defun comment-nonascii-afpt (&optional arg ispec) 
  "Returns a copy of nonascii after point if any, nil otherwise "
  (interactive "P\np")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward "^[:nonascii:]")
      (thatpt-comment 'nonascii arg ispec))))

;;;###autoload
(defun doublequote-nonascii-afpt (&optional arg ispec) 
  "Doublequotes nonascii after point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'nonascii 'doublequote arg ispec))

;;;###autoload
(defun singlequote-nonascii-afpt (&optional arg ispec) 
  "Singlequotes nonascii after point if any, does nothing otherwise " 
  (interactive "P\np")
  (thatpt-delim 'nonascii 'singlequote arg ispec))

;;;###autoload
(defun parenthese-nonascii-afpt (&optional arg ispec) 
  "Parentizes nonascii after point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'nonascii 'parentize arg ispec))

;;;###autoload
(defun brace-nonascii-afpt (&optional arg ispec) 
  "Braces nonascii after point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'nonascii 'brace arg ispec))

;;;###autoload
(defun bracket-nonascii-afpt (&optional arg ispec) 
  "Brackets nonascii after point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'nonascii 'bracket arg ispec))

;;;###autoload
(defun mark-nonascii-afpt ()
  "Marks nonascii after point if any, does nothing otherwise "
  (interactive "*")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward "^[:nonascii:]")
      (thatpt-mark 'nonascii))))

;;;###autoload
(defun forward-nonascii-afpt (&optional arg ispec) 
  "Moves forward over nonascii after point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-forward 'nonascii arg ispec))


;;;###autoload
(defun number-afpt (&optional arg ispec) 
  "Returns number after point if any, nil otherwise"
  (interactive "P\np")
  (or arg (setq arg 1)) 
  (save-excursion
    (thatpt 'number arg ispec)))

;;;###autoload
(defun bounds-of-number-afpt (&optional arg ispec) 
  "Returns border of number after point if any, nil otherwise "
  (interactive "P\np")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward " \t\n\r\f")
      (let ((number (thatpt-bounds 'number arg ispec)))
	(when ispec (message "   %s" number))
	number))))

;;;###autoload
(defun number-afpt-beginning-position (&optional arg ispec) 
  "Returns beginning of number after point if any, nil otherwise "
  (interactive "P\np")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward " \t\n\r\f")
      (thatpt-beginning 'number arg ispec))))

;;;###autoload
(defun number-afpt-end-position (&optional arg ispec) 
  "Returns end position of number after point if any, nil otherwise "
  (interactive "P\np")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward " \t\n\r\f")
      (thatpt-end 'number arg ispec))))

;;;###autoload
(defun length-of-number-afpt (&optional arg ispec) 
  "Returns end position of number after point if any, nil otherwise "
  (interactive "P\np")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward " \t\n\r\f")
      (thatpt-length 'number arg ispec))))

;;;###autoload
(defun copy-number-afpt (&optional arg ispec) 
  "Returns a copy of number after point if any, nil otherwise "
  (interactive "P\np")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward " \t\n\r\f")
      (thatpt-copy 'number arg ispec))))

;;;###autoload
(defun separate-number-afpt (&optional arg ispec) 
  "Returns a copy of number after point if any, nil otherwise "
  (interactive "P\np")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward " \t\n\r\f")
      (thatpt-separate 'number arg ispec))))

;;;###autoload
(defun comment-number-afpt (&optional arg ispec) 
  "Returns a copy of number after point if any, nil otherwise "
  (interactive "P\np")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward " \t\n\r\f")
      (thatpt-comment 'number arg ispec))))

;;;###autoload
(defun doublequote-number-afpt (&optional arg ispec) 
  "Doublequotes number after point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'number 'doublequote arg ispec))

;;;###autoload
(defun singlequote-number-afpt (&optional arg ispec) 
  "Singlequotes number after point if any, does nothing otherwise " 
  (interactive "P\np")
  (thatpt-delim 'number 'singlequote arg ispec))

;;;###autoload
(defun parenthese-number-afpt (&optional arg ispec) 
  "Parentizes number after point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'number 'parentize arg ispec))

;;;###autoload
(defun brace-number-afpt (&optional arg ispec) 
  "Braces number after point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'number 'brace arg ispec))

;;;###autoload
(defun bracket-number-afpt (&optional arg ispec) 
  "Brackets number after point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'number 'bracket arg ispec))

;;;###autoload
(defun mark-number-afpt ()
  "Marks number after point if any, does nothing otherwise "
  (interactive "*")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward " \t\n\r\f")
      (thatpt-mark 'number))))

;;;###autoload
(defun forward-number-afpt (&optional arg ispec) 
  "Moves forward over number after point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-forward 'number arg ispec))


;;;###autoload
(defun page-afpt (&optional arg ispec) 
  "Returns page after point if any, nil otherwise"
  (interactive "P\np")
  (or arg (setq arg 1)) 
  (save-excursion
    (thatpt 'page arg ispec)))

;;;###autoload
(defun bounds-of-page-afpt (&optional arg ispec) 
  "Returns border of page after point if any, nil otherwise "
  (interactive "P\np")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward " \t\n\r\f")
      (let ((page (thatpt-bounds 'page arg ispec)))
	(when ispec (message "   %s" page))
	page))))

;;;###autoload
(defun page-afpt-beginning-position (&optional arg ispec) 
  "Returns beginning of page after point if any, nil otherwise "
  (interactive "P\np")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward " \t\n\r\f")
      (thatpt-beginning 'page arg ispec))))

;;;###autoload
(defun page-afpt-end-position (&optional arg ispec) 
  "Returns end position of page after point if any, nil otherwise "
  (interactive "P\np")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward " \t\n\r\f")
      (thatpt-end 'page arg ispec))))

;;;###autoload
(defun length-of-page-afpt (&optional arg ispec) 
  "Returns end position of page after point if any, nil otherwise "
  (interactive "P\np")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward " \t\n\r\f")
      (thatpt-length 'page arg ispec))))

;;;###autoload
(defun copy-page-afpt (&optional arg ispec) 
  "Returns a copy of page after point if any, nil otherwise "
  (interactive "P\np")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward " \t\n\r\f")
      (thatpt-copy 'page arg ispec))))

;;;###autoload
(defun separate-page-afpt (&optional arg ispec) 
  "Returns a copy of page after point if any, nil otherwise "
  (interactive "P\np")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward " \t\n\r\f")
      (thatpt-separate 'page arg ispec))))

;;;###autoload
(defun comment-page-afpt (&optional arg ispec) 
  "Returns a copy of page after point if any, nil otherwise "
  (interactive "P\np")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward " \t\n\r\f")
      (thatpt-comment 'page arg ispec))))

;;;###autoload
(defun doublequote-page-afpt (&optional arg ispec) 
  "Doublequotes page after point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'page 'doublequote arg ispec))

;;;###autoload
(defun singlequote-page-afpt (&optional arg ispec) 
  "Singlequotes page after point if any, does nothing otherwise " 
  (interactive "P\np")
  (thatpt-delim 'page 'singlequote arg ispec))

;;;###autoload
(defun parenthese-page-afpt (&optional arg ispec) 
  "Parentizes page after point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'page 'parentize arg ispec))

;;;###autoload
(defun brace-page-afpt (&optional arg ispec) 
  "Braces page after point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'page 'brace arg ispec))

;;;###autoload
(defun bracket-page-afpt (&optional arg ispec) 
  "Brackets page after point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'page 'bracket arg ispec))

;;;###autoload
(defun mark-page-afpt ()
  "Marks page after point if any, does nothing otherwise "
  (interactive "*")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward " \t\n\r\f")
      (thatpt-mark 'page))))

;;;###autoload
(defun forward-page-afpt (&optional arg ispec) 
  "Moves forward over page after point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-forward 'page arg ispec))


;;;###autoload
(defun paragraph-afpt (&optional arg ispec) 
  "Returns paragraph after point if any, nil otherwise"
  (interactive "P\np")
  (or arg (setq arg 1)) 
  (save-excursion
    (thatpt 'paragraph arg ispec)))

;;;###autoload
(defun bounds-of-paragraph-afpt (&optional arg ispec) 
  "Returns border of paragraph after point if any, nil otherwise "
  (interactive "P\np")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward " \t\n\r\f")
      (let ((paragraph (thatpt-bounds 'paragraph arg ispec)))
	(when ispec (message "   %s" paragraph))
	paragraph))))

;;;###autoload
(defun paragraph-afpt-beginning-position (&optional arg ispec) 
  "Returns beginning of paragraph after point if any, nil otherwise "
  (interactive "P\np")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward " \t\n\r\f")
      (thatpt-beginning 'paragraph arg ispec))))

;;;###autoload
(defun paragraph-afpt-end-position (&optional arg ispec) 
  "Returns end position of paragraph after point if any, nil otherwise "
  (interactive "P\np")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward " \t\n\r\f")
      (thatpt-end 'paragraph arg ispec))))

;;;###autoload
(defun length-of-paragraph-afpt (&optional arg ispec) 
  "Returns end position of paragraph after point if any, nil otherwise "
  (interactive "P\np")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward " \t\n\r\f")
      (thatpt-length 'paragraph arg ispec))))

;;;###autoload
(defun copy-paragraph-afpt (&optional arg ispec) 
  "Returns a copy of paragraph after point if any, nil otherwise "
  (interactive "P\np")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward " \t\n\r\f")
      (thatpt-copy 'paragraph arg ispec))))

;;;###autoload
(defun separate-paragraph-afpt (&optional arg ispec) 
  "Returns a copy of paragraph after point if any, nil otherwise "
  (interactive "P\np")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward " \t\n\r\f")
      (thatpt-separate 'paragraph arg ispec))))

;;;###autoload
(defun comment-paragraph-afpt (&optional arg ispec) 
  "Returns a copy of paragraph after point if any, nil otherwise "
  (interactive "P\np")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward " \t\n\r\f")
      (thatpt-comment 'paragraph arg ispec))))

;;;###autoload
(defun doublequote-paragraph-afpt (&optional arg ispec) 
  "Doublequotes paragraph after point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'paragraph 'doublequote arg ispec))

;;;###autoload
(defun singlequote-paragraph-afpt (&optional arg ispec) 
  "Singlequotes paragraph after point if any, does nothing otherwise " 
  (interactive "P\np")
  (thatpt-delim 'paragraph 'singlequote arg ispec))

;;;###autoload
(defun parenthese-paragraph-afpt (&optional arg ispec) 
  "Parentizes paragraph after point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'paragraph 'parentize arg ispec))

;;;###autoload
(defun brace-paragraph-afpt (&optional arg ispec) 
  "Braces paragraph after point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'paragraph 'brace arg ispec))

;;;###autoload
(defun bracket-paragraph-afpt (&optional arg ispec) 
  "Brackets paragraph after point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'paragraph 'bracket arg ispec))

;;;###autoload
(defun mark-paragraph-afpt ()
  "Marks paragraph after point if any, does nothing otherwise "
  (interactive "*")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward " \t\n\r\f")
      (thatpt-mark 'paragraph))))

;;;###autoload
(defun forward-paragraph-afpt (&optional arg ispec) 
  "Moves forward over paragraph after point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-forward 'paragraph arg ispec))


;;;###autoload
(defun paren-afpt (&optional arg ispec) 
  "Returns paren after point if any, nil otherwise"
  (interactive "P\np")
  (or arg (setq arg 1)) 
  (save-excursion
    (thatpt 'paren arg ispec)))

;;;###autoload
(defun bounds-of-paren-afpt (&optional arg ispec) 
  "Returns border of paren after point if any, nil otherwise "
  (interactive "P\np")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward " \t\n\r\f")
      (let ((paren (thatpt-bounds 'paren arg ispec)))
	(when ispec (message "   %s" paren))
	paren))))

;;;###autoload
(defun paren-afpt-beginning-position (&optional arg ispec) 
  "Returns beginning of paren after point if any, nil otherwise "
  (interactive "P\np")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward " \t\n\r\f")
      (thatpt-beginning 'paren arg ispec))))

;;;###autoload
(defun paren-afpt-end-position (&optional arg ispec) 
  "Returns end position of paren after point if any, nil otherwise "
  (interactive "P\np")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward " \t\n\r\f")
      (thatpt-end 'paren arg ispec))))

;;;###autoload
(defun length-of-paren-afpt (&optional arg ispec) 
  "Returns end position of paren after point if any, nil otherwise "
  (interactive "P\np")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward " \t\n\r\f")
      (thatpt-length 'paren arg ispec))))

;;;###autoload
(defun copy-paren-afpt (&optional arg ispec) 
  "Returns a copy of paren after point if any, nil otherwise "
  (interactive "P\np")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward " \t\n\r\f")
      (thatpt-copy 'paren arg ispec))))

;;;###autoload
(defun separate-paren-afpt (&optional arg ispec) 
  "Returns a copy of paren after point if any, nil otherwise "
  (interactive "P\np")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward " \t\n\r\f")
      (thatpt-separate 'paren arg ispec))))

;;;###autoload
(defun comment-paren-afpt (&optional arg ispec) 
  "Returns a copy of paren after point if any, nil otherwise "
  (interactive "P\np")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward " \t\n\r\f")
      (thatpt-comment 'paren arg ispec))))

;;;###autoload
(defun doublequote-paren-afpt (&optional arg ispec) 
  "Doublequotes paren after point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'paren 'doublequote arg ispec))

;;;###autoload
(defun singlequote-paren-afpt (&optional arg ispec) 
  "Singlequotes paren after point if any, does nothing otherwise " 
  (interactive "P\np")
  (thatpt-delim 'paren 'singlequote arg ispec))

;;;###autoload
(defun parenthese-paren-afpt (&optional arg ispec) 
  "Parentizes paren after point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'paren 'parentize arg ispec))

;;;###autoload
(defun brace-paren-afpt (&optional arg ispec) 
  "Braces paren after point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'paren 'brace arg ispec))

;;;###autoload
(defun bracket-paren-afpt (&optional arg ispec) 
  "Brackets paren after point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'paren 'bracket arg ispec))

;;;###autoload
(defun mark-paren-afpt ()
  "Marks paren after point if any, does nothing otherwise "
  (interactive "*")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward " \t\n\r\f")
      (thatpt-mark 'paren))))

;;;###autoload
(defun forward-paren-afpt (&optional arg ispec) 
  "Moves forward over paren after point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-forward 'paren arg ispec))


;;;###autoload
(defun phone-afpt (&optional arg ispec) 
  "Returns phone after point if any, nil otherwise"
  (interactive "P\np")
  (or arg (setq arg 1)) 
  (save-excursion
    (thatpt 'phone arg ispec)))

;;;###autoload
(defun bounds-of-phone-afpt (&optional arg ispec) 
  "Returns border of phone after point if any, nil otherwise "
  (interactive "P\np")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward " \t\n\r\f")
      (let ((phone (thatpt-bounds 'phone arg ispec)))
	(when ispec (message "   %s" phone))
	phone))))

;;;###autoload
(defun phone-afpt-beginning-position (&optional arg ispec) 
  "Returns beginning of phone after point if any, nil otherwise "
  (interactive "P\np")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward " \t\n\r\f")
      (thatpt-beginning 'phone arg ispec))))

;;;###autoload
(defun phone-afpt-end-position (&optional arg ispec) 
  "Returns end position of phone after point if any, nil otherwise "
  (interactive "P\np")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward " \t\n\r\f")
      (thatpt-end 'phone arg ispec))))

;;;###autoload
(defun length-of-phone-afpt (&optional arg ispec) 
  "Returns end position of phone after point if any, nil otherwise "
  (interactive "P\np")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward " \t\n\r\f")
      (thatpt-length 'phone arg ispec))))

;;;###autoload
(defun copy-phone-afpt (&optional arg ispec) 
  "Returns a copy of phone after point if any, nil otherwise "
  (interactive "P\np")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward " \t\n\r\f")
      (thatpt-copy 'phone arg ispec))))

;;;###autoload
(defun separate-phone-afpt (&optional arg ispec) 
  "Returns a copy of phone after point if any, nil otherwise "
  (interactive "P\np")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward " \t\n\r\f")
      (thatpt-separate 'phone arg ispec))))

;;;###autoload
(defun comment-phone-afpt (&optional arg ispec) 
  "Returns a copy of phone after point if any, nil otherwise "
  (interactive "P\np")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward " \t\n\r\f")
      (thatpt-comment 'phone arg ispec))))

;;;###autoload
(defun doublequote-phone-afpt (&optional arg ispec) 
  "Doublequotes phone after point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'phone 'doublequote arg ispec))

;;;###autoload
(defun singlequote-phone-afpt (&optional arg ispec) 
  "Singlequotes phone after point if any, does nothing otherwise " 
  (interactive "P\np")
  (thatpt-delim 'phone 'singlequote arg ispec))

;;;###autoload
(defun parenthese-phone-afpt (&optional arg ispec) 
  "Parentizes phone after point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'phone 'parentize arg ispec))

;;;###autoload
(defun brace-phone-afpt (&optional arg ispec) 
  "Braces phone after point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'phone 'brace arg ispec))

;;;###autoload
(defun bracket-phone-afpt (&optional arg ispec) 
  "Brackets phone after point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'phone 'bracket arg ispec))

;;;###autoload
(defun mark-phone-afpt ()
  "Marks phone after point if any, does nothing otherwise "
  (interactive "*")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward " \t\n\r\f")
      (thatpt-mark 'phone))))

;;;###autoload
(defun forward-phone-afpt (&optional arg ispec) 
  "Moves forward over phone after point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-forward 'phone arg ispec))


;;;###autoload
(defun print-afpt (&optional arg ispec) 
  "Returns print after point if any, nil otherwise"
  (interactive "P\np")
  (or arg (setq arg 1)) 
  (save-excursion
    (thatpt 'print arg ispec)))

;;;###autoload
(defun bounds-of-print-afpt (&optional arg ispec) 
  "Returns border of print after point if any, nil otherwise "
  (interactive "P\np")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward "^[:print:]")
      (let ((print (thatpt-bounds 'print arg ispec)))
	(when ispec (message "   %s" print))
	print))))

;;;###autoload
(defun print-afpt-beginning-position (&optional arg ispec) 
  "Returns beginning of print after point if any, nil otherwise "
  (interactive "P\np")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward "^[:print:]")
      (thatpt-beginning 'print arg ispec))))

;;;###autoload
(defun print-afpt-end-position (&optional arg ispec) 
  "Returns end position of print after point if any, nil otherwise "
  (interactive "P\np")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward "^[:print:]")
      (thatpt-end 'print arg ispec))))

;;;###autoload
(defun length-of-print-afpt (&optional arg ispec) 
  "Returns end position of print after point if any, nil otherwise "
  (interactive "P\np")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward "^[:print:]")
      (thatpt-length 'print arg ispec))))

;;;###autoload
(defun copy-print-afpt (&optional arg ispec) 
  "Returns a copy of print after point if any, nil otherwise "
  (interactive "P\np")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward "^[:print:]")
      (thatpt-copy 'print arg ispec))))

;;;###autoload
(defun separate-print-afpt (&optional arg ispec) 
  "Returns a copy of print after point if any, nil otherwise "
  (interactive "P\np")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward "^[:print:]")
      (thatpt-separate 'print arg ispec))))

;;;###autoload
(defun comment-print-afpt (&optional arg ispec) 
  "Returns a copy of print after point if any, nil otherwise "
  (interactive "P\np")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward "^[:print:]")
      (thatpt-comment 'print arg ispec))))

;;;###autoload
(defun doublequote-print-afpt (&optional arg ispec) 
  "Doublequotes print after point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'print 'doublequote arg ispec))

;;;###autoload
(defun singlequote-print-afpt (&optional arg ispec) 
  "Singlequotes print after point if any, does nothing otherwise " 
  (interactive "P\np")
  (thatpt-delim 'print 'singlequote arg ispec))

;;;###autoload
(defun parenthese-print-afpt (&optional arg ispec) 
  "Parentizes print after point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'print 'parentize arg ispec))

;;;###autoload
(defun brace-print-afpt (&optional arg ispec) 
  "Braces print after point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'print 'brace arg ispec))

;;;###autoload
(defun bracket-print-afpt (&optional arg ispec) 
  "Brackets print after point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'print 'bracket arg ispec))

;;;###autoload
(defun mark-print-afpt ()
  "Marks print after point if any, does nothing otherwise "
  (interactive "*")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward "^[:print:]")
      (thatpt-mark 'print))))

;;;###autoload
(defun forward-print-afpt (&optional arg ispec) 
  "Moves forward over print after point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-forward 'print arg ispec))


;;;###autoload
(defun punct-afpt (&optional arg ispec) 
  "Returns punct after point if any, nil otherwise"
  (interactive "P\np")
  (or arg (setq arg 1)) 
  (save-excursion
    (thatpt 'punct arg ispec)))

;;;###autoload
(defun bounds-of-punct-afpt (&optional arg ispec) 
  "Returns border of punct after point if any, nil otherwise "
  (interactive "P\np")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward "^[:punct:]")
      (let ((punct (thatpt-bounds 'punct arg ispec)))
	(when ispec (message "   %s" punct))
	punct))))

;;;###autoload
(defun punct-afpt-beginning-position (&optional arg ispec) 
  "Returns beginning of punct after point if any, nil otherwise "
  (interactive "P\np")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward "^[:punct:]")
      (thatpt-beginning 'punct arg ispec))))

;;;###autoload
(defun punct-afpt-end-position (&optional arg ispec) 
  "Returns end position of punct after point if any, nil otherwise "
  (interactive "P\np")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward "^[:punct:]")
      (thatpt-end 'punct arg ispec))))

;;;###autoload
(defun length-of-punct-afpt (&optional arg ispec) 
  "Returns end position of punct after point if any, nil otherwise "
  (interactive "P\np")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward "^[:punct:]")
      (thatpt-length 'punct arg ispec))))

;;;###autoload
(defun copy-punct-afpt (&optional arg ispec) 
  "Returns a copy of punct after point if any, nil otherwise "
  (interactive "P\np")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward "^[:punct:]")
      (thatpt-copy 'punct arg ispec))))

;;;###autoload
(defun separate-punct-afpt (&optional arg ispec) 
  "Returns a copy of punct after point if any, nil otherwise "
  (interactive "P\np")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward "^[:punct:]")
      (thatpt-separate 'punct arg ispec))))

;;;###autoload
(defun comment-punct-afpt (&optional arg ispec) 
  "Returns a copy of punct after point if any, nil otherwise "
  (interactive "P\np")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward "^[:punct:]")
      (thatpt-comment 'punct arg ispec))))

;;;###autoload
(defun doublequote-punct-afpt (&optional arg ispec) 
  "Doublequotes punct after point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'punct 'doublequote arg ispec))

;;;###autoload
(defun singlequote-punct-afpt (&optional arg ispec) 
  "Singlequotes punct after point if any, does nothing otherwise " 
  (interactive "P\np")
  (thatpt-delim 'punct 'singlequote arg ispec))

;;;###autoload
(defun parenthese-punct-afpt (&optional arg ispec) 
  "Parentizes punct after point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'punct 'parentize arg ispec))

;;;###autoload
(defun brace-punct-afpt (&optional arg ispec) 
  "Braces punct after point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'punct 'brace arg ispec))

;;;###autoload
(defun bracket-punct-afpt (&optional arg ispec) 
  "Brackets punct after point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'punct 'bracket arg ispec))

;;;###autoload
(defun mark-punct-afpt ()
  "Marks punct after point if any, does nothing otherwise "
  (interactive "*")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward "^[:punct:]")
      (thatpt-mark 'punct))))

;;;###autoload
(defun forward-punct-afpt (&optional arg ispec) 
  "Moves forward over punct after point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-forward 'punct arg ispec))


;;;###autoload
(defun region-afpt (&optional arg ispec) 
  "Returns region after point if any, nil otherwise"
  (interactive "P\np")
  (or arg (setq arg 1)) 
  (save-excursion
    (thatpt 'region arg ispec)))

;;;###autoload
(defun bounds-of-region-afpt (&optional arg ispec) 
  "Returns border of region after point if any, nil otherwise "
  (interactive "P\np")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward " \t\n\r\f")
      (let ((region (thatpt-bounds 'region arg ispec)))
	(when ispec (message "   %s" region))
	region))))

;;;###autoload
(defun region-afpt-beginning-position (&optional arg ispec) 
  "Returns beginning of region after point if any, nil otherwise "
  (interactive "P\np")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward " \t\n\r\f")
      (thatpt-beginning 'region arg ispec))))

;;;###autoload
(defun region-afpt-end-position (&optional arg ispec) 
  "Returns end position of region after point if any, nil otherwise "
  (interactive "P\np")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward " \t\n\r\f")
      (thatpt-end 'region arg ispec))))

;;;###autoload
(defun length-of-region-afpt (&optional arg ispec) 
  "Returns end position of region after point if any, nil otherwise "
  (interactive "P\np")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward " \t\n\r\f")
      (thatpt-length 'region arg ispec))))

;;;###autoload
(defun copy-region-afpt (&optional arg ispec) 
  "Returns a copy of region after point if any, nil otherwise "
  (interactive "P\np")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward " \t\n\r\f")
      (thatpt-copy 'region arg ispec))))

;;;###autoload
(defun separate-region-afpt (&optional arg ispec) 
  "Returns a copy of region after point if any, nil otherwise "
  (interactive "P\np")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward " \t\n\r\f")
      (thatpt-separate 'region arg ispec))))

;;;###autoload
(defun comment-region-afpt (&optional arg ispec) 
  "Returns a copy of region after point if any, nil otherwise "
  (interactive "P\np")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward " \t\n\r\f")
      (thatpt-comment 'region arg ispec))))

;;;###autoload
(defun doublequote-region-afpt (&optional arg ispec) 
  "Doublequotes region after point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'region 'doublequote arg ispec))

;;;###autoload
(defun singlequote-region-afpt (&optional arg ispec) 
  "Singlequotes region after point if any, does nothing otherwise " 
  (interactive "P\np")
  (thatpt-delim 'region 'singlequote arg ispec))

;;;###autoload
(defun parenthese-region-afpt (&optional arg ispec) 
  "Parentizes region after point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'region 'parentize arg ispec))

;;;###autoload
(defun brace-region-afpt (&optional arg ispec) 
  "Braces region after point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'region 'brace arg ispec))

;;;###autoload
(defun bracket-region-afpt (&optional arg ispec) 
  "Brackets region after point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'region 'bracket arg ispec))

;;;###autoload
(defun mark-region-afpt ()
  "Marks region after point if any, does nothing otherwise "
  (interactive "*")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward " \t\n\r\f")
      (thatpt-mark 'region))))

;;;###autoload
(defun forward-region-afpt (&optional arg ispec) 
  "Moves forward over region after point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-forward 'region arg ispec))


;;;###autoload
(defun sentence-afpt (&optional arg ispec) 
  "Returns sentence after point if any, nil otherwise"
  (interactive "P\np")
  (or arg (setq arg 1)) 
  (save-excursion
    (thatpt 'sentence arg ispec)))

;;;###autoload
(defun bounds-of-sentence-afpt (&optional arg ispec) 
  "Returns border of sentence after point if any, nil otherwise "
  (interactive "P\np")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward " \t\n\r\f")
      (let ((sentence (thatpt-bounds 'sentence arg ispec)))
	(when ispec (message "   %s" sentence))
	sentence))))

;;;###autoload
(defun sentence-afpt-beginning-position (&optional arg ispec) 
  "Returns beginning of sentence after point if any, nil otherwise "
  (interactive "P\np")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward " \t\n\r\f")
      (thatpt-beginning 'sentence arg ispec))))

;;;###autoload
(defun sentence-afpt-end-position (&optional arg ispec) 
  "Returns end position of sentence after point if any, nil otherwise "
  (interactive "P\np")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward " \t\n\r\f")
      (thatpt-end 'sentence arg ispec))))

;;;###autoload
(defun length-of-sentence-afpt (&optional arg ispec) 
  "Returns end position of sentence after point if any, nil otherwise "
  (interactive "P\np")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward " \t\n\r\f")
      (thatpt-length 'sentence arg ispec))))

;;;###autoload
(defun copy-sentence-afpt (&optional arg ispec) 
  "Returns a copy of sentence after point if any, nil otherwise "
  (interactive "P\np")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward " \t\n\r\f")
      (thatpt-copy 'sentence arg ispec))))

;;;###autoload
(defun separate-sentence-afpt (&optional arg ispec) 
  "Returns a copy of sentence after point if any, nil otherwise "
  (interactive "P\np")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward " \t\n\r\f")
      (thatpt-separate 'sentence arg ispec))))

;;;###autoload
(defun comment-sentence-afpt (&optional arg ispec) 
  "Returns a copy of sentence after point if any, nil otherwise "
  (interactive "P\np")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward " \t\n\r\f")
      (thatpt-comment 'sentence arg ispec))))

;;;###autoload
(defun doublequote-sentence-afpt (&optional arg ispec) 
  "Doublequotes sentence after point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'sentence 'doublequote arg ispec))

;;;###autoload
(defun singlequote-sentence-afpt (&optional arg ispec) 
  "Singlequotes sentence after point if any, does nothing otherwise " 
  (interactive "P\np")
  (thatpt-delim 'sentence 'singlequote arg ispec))

;;;###autoload
(defun parenthese-sentence-afpt (&optional arg ispec) 
  "Parentizes sentence after point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'sentence 'parentize arg ispec))

;;;###autoload
(defun brace-sentence-afpt (&optional arg ispec) 
  "Braces sentence after point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'sentence 'brace arg ispec))

;;;###autoload
(defun bracket-sentence-afpt (&optional arg ispec) 
  "Brackets sentence after point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'sentence 'bracket arg ispec))

;;;###autoload
(defun mark-sentence-afpt ()
  "Marks sentence after point if any, does nothing otherwise "
  (interactive "*")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward " \t\n\r\f")
      (thatpt-mark 'sentence))))

;;;###autoload
(defun forward-sentence-afpt (&optional arg ispec) 
  "Moves forward over sentence after point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-forward 'sentence arg ispec))


;;;###autoload
(defun sexp-afpt (&optional arg ispec) 
  "Returns sexp after point if any, nil otherwise"
  (interactive "P\np")
  (or arg (setq arg 1)) 
  (save-excursion
    (thatpt 'sexp arg ispec)))

;;;###autoload
(defun bounds-of-sexp-afpt (&optional arg ispec) 
  "Returns border of sexp after point if any, nil otherwise "
  (interactive "P\np")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward " \t\n\r\f")
      (let ((sexp (thatpt-bounds 'sexp arg ispec)))
	(when ispec (message "   %s" sexp))
	sexp))))

;;;###autoload
(defun sexp-afpt-beginning-position (&optional arg ispec) 
  "Returns beginning of sexp after point if any, nil otherwise "
  (interactive "P\np")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward " \t\n\r\f")
      (thatpt-beginning 'sexp arg ispec))))

;;;###autoload
(defun sexp-afpt-end-position (&optional arg ispec) 
  "Returns end position of sexp after point if any, nil otherwise "
  (interactive "P\np")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward " \t\n\r\f")
      (thatpt-end 'sexp arg ispec))))

;;;###autoload
(defun length-of-sexp-afpt (&optional arg ispec) 
  "Returns end position of sexp after point if any, nil otherwise "
  (interactive "P\np")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward " \t\n\r\f")
      (thatpt-length 'sexp arg ispec))))

;;;###autoload
(defun copy-sexp-afpt (&optional arg ispec) 
  "Returns a copy of sexp after point if any, nil otherwise "
  (interactive "P\np")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward " \t\n\r\f")
      (thatpt-copy 'sexp arg ispec))))

;;;###autoload
(defun separate-sexp-afpt (&optional arg ispec) 
  "Returns a copy of sexp after point if any, nil otherwise "
  (interactive "P\np")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward " \t\n\r\f")
      (thatpt-separate 'sexp arg ispec))))

;;;###autoload
(defun comment-sexp-afpt (&optional arg ispec) 
  "Returns a copy of sexp after point if any, nil otherwise "
  (interactive "P\np")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward " \t\n\r\f")
      (thatpt-comment 'sexp arg ispec))))

;;;###autoload
(defun doublequote-sexp-afpt (&optional arg ispec) 
  "Doublequotes sexp after point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'sexp 'doublequote arg ispec))

;;;###autoload
(defun singlequote-sexp-afpt (&optional arg ispec) 
  "Singlequotes sexp after point if any, does nothing otherwise " 
  (interactive "P\np")
  (thatpt-delim 'sexp 'singlequote arg ispec))

;;;###autoload
(defun parenthese-sexp-afpt (&optional arg ispec) 
  "Parentizes sexp after point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'sexp 'parentize arg ispec))

;;;###autoload
(defun brace-sexp-afpt (&optional arg ispec) 
  "Braces sexp after point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'sexp 'brace arg ispec))

;;;###autoload
(defun bracket-sexp-afpt (&optional arg ispec) 
  "Brackets sexp after point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'sexp 'bracket arg ispec))

;;;###autoload
(defun mark-sexp-afpt ()
  "Marks sexp after point if any, does nothing otherwise "
  (interactive "*")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward " \t\n\r\f")
      (thatpt-mark 'sexp))))

;;;###autoload
(defun forward-sexp-afpt (&optional arg ispec) 
  "Moves forward over sexp after point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-forward 'sexp arg ispec))


;;;###autoload
(defun space-afpt (&optional arg ispec) 
  "Returns space after point if any, nil otherwise"
  (interactive "P\np")
  (or arg (setq arg 1)) 
  (save-excursion
    (thatpt 'space arg ispec)))

;;;###autoload
(defun bounds-of-space-afpt (&optional arg ispec) 
  "Returns border of space after point if any, nil otherwise "
  (interactive "P\np")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward "^[:space:]")
      (let ((space (thatpt-bounds 'space arg ispec)))
	(when ispec (message "   %s" space))
	space))))

;;;###autoload
(defun space-afpt-beginning-position (&optional arg ispec) 
  "Returns beginning of space after point if any, nil otherwise "
  (interactive "P\np")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward "^[:space:]")
      (thatpt-beginning 'space arg ispec))))

;;;###autoload
(defun space-afpt-end-position (&optional arg ispec) 
  "Returns end position of space after point if any, nil otherwise "
  (interactive "P\np")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward "^[:space:]")
      (thatpt-end 'space arg ispec))))

;;;###autoload
(defun length-of-space-afpt (&optional arg ispec) 
  "Returns end position of space after point if any, nil otherwise "
  (interactive "P\np")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward "^[:space:]")
      (thatpt-length 'space arg ispec))))

;;;###autoload
(defun copy-space-afpt (&optional arg ispec) 
  "Returns a copy of space after point if any, nil otherwise "
  (interactive "P\np")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward "^[:space:]")
      (thatpt-copy 'space arg ispec))))

;;;###autoload
(defun separate-space-afpt (&optional arg ispec) 
  "Returns a copy of space after point if any, nil otherwise "
  (interactive "P\np")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward "^[:space:]")
      (thatpt-separate 'space arg ispec))))

;;;###autoload
(defun comment-space-afpt (&optional arg ispec) 
  "Returns a copy of space after point if any, nil otherwise "
  (interactive "P\np")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward "^[:space:]")
      (thatpt-comment 'space arg ispec))))

;;;###autoload
(defun doublequote-space-afpt (&optional arg ispec) 
  "Doublequotes space after point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'space 'doublequote arg ispec))

;;;###autoload
(defun singlequote-space-afpt (&optional arg ispec) 
  "Singlequotes space after point if any, does nothing otherwise " 
  (interactive "P\np")
  (thatpt-delim 'space 'singlequote arg ispec))

;;;###autoload
(defun parenthese-space-afpt (&optional arg ispec) 
  "Parentizes space after point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'space 'parentize arg ispec))

;;;###autoload
(defun brace-space-afpt (&optional arg ispec) 
  "Braces space after point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'space 'brace arg ispec))

;;;###autoload
(defun bracket-space-afpt (&optional arg ispec) 
  "Brackets space after point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'space 'bracket arg ispec))

;;;###autoload
(defun mark-space-afpt ()
  "Marks space after point if any, does nothing otherwise "
  (interactive "*")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward "^[:space:]")
      (thatpt-mark 'space))))

;;;###autoload
(defun forward-space-afpt (&optional arg ispec) 
  "Moves forward over space after point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-forward 'space arg ispec))


;;;###autoload
(defun string-afpt (&optional arg ispec) 
  "Returns string after point if any, nil otherwise"
  (interactive "P\np")
  (or arg (setq arg 1)) 
  (save-excursion
    (thatpt 'string arg ispec)))

;;;###autoload
(defun bounds-of-string-afpt (&optional arg ispec) 
  "Returns border of string after point if any, nil otherwise "
  (interactive "P\np")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward " \t\n\r\f")
      (let ((string (thatpt-bounds 'string arg ispec)))
	(when ispec (message "   %s" string))
	string))))

;;;###autoload
(defun string-afpt-beginning-position (&optional arg ispec) 
  "Returns beginning of string after point if any, nil otherwise "
  (interactive "P\np")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward " \t\n\r\f")
      (thatpt-beginning 'string arg ispec))))

;;;###autoload
(defun string-afpt-end-position (&optional arg ispec) 
  "Returns end position of string after point if any, nil otherwise "
  (interactive "P\np")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward " \t\n\r\f")
      (thatpt-end 'string arg ispec))))

;;;###autoload
(defun length-of-string-afpt (&optional arg ispec) 
  "Returns end position of string after point if any, nil otherwise "
  (interactive "P\np")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward " \t\n\r\f")
      (thatpt-length 'string arg ispec))))

;;;###autoload
(defun copy-string-afpt (&optional arg ispec) 
  "Returns a copy of string after point if any, nil otherwise "
  (interactive "P\np")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward " \t\n\r\f")
      (thatpt-copy 'string arg ispec))))

;;;###autoload
(defun separate-string-afpt (&optional arg ispec) 
  "Returns a copy of string after point if any, nil otherwise "
  (interactive "P\np")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward " \t\n\r\f")
      (thatpt-separate 'string arg ispec))))

;;;###autoload
(defun comment-string-afpt (&optional arg ispec) 
  "Returns a copy of string after point if any, nil otherwise "
  (interactive "P\np")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward " \t\n\r\f")
      (thatpt-comment 'string arg ispec))))

;;;###autoload
(defun doublequote-string-afpt (&optional arg ispec) 
  "Doublequotes string after point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'string 'doublequote arg ispec))

;;;###autoload
(defun singlequote-string-afpt (&optional arg ispec) 
  "Singlequotes string after point if any, does nothing otherwise " 
  (interactive "P\np")
  (thatpt-delim 'string 'singlequote arg ispec))

;;;###autoload
(defun parenthese-string-afpt (&optional arg ispec) 
  "Parentizes string after point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'string 'parentize arg ispec))

;;;###autoload
(defun brace-string-afpt (&optional arg ispec) 
  "Braces string after point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'string 'brace arg ispec))

;;;###autoload
(defun bracket-string-afpt (&optional arg ispec) 
  "Brackets string after point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'string 'bracket arg ispec))

;;;###autoload
(defun mark-string-afpt ()
  "Marks string after point if any, does nothing otherwise "
  (interactive "*")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward " \t\n\r\f")
      (thatpt-mark 'string))))

;;;###autoload
(defun forward-string-afpt (&optional arg ispec) 
  "Moves forward over string after point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-forward 'string arg ispec))


;;;###autoload
(defun symbol-afpt (&optional arg ispec) 
  "Returns symbol after point if any, nil otherwise"
  (interactive "P\np")
  (or arg (setq arg 1)) 
  (save-excursion
    (thatpt 'symbol arg ispec)))

;;;###autoload
(defun bounds-of-symbol-afpt (&optional arg ispec) 
  "Returns border of symbol after point if any, nil otherwise "
  (interactive "P\np")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward " \t\n\r\f")
      (let ((symbol (thatpt-bounds 'symbol arg ispec)))
	(when ispec (message "   %s" symbol))
	symbol))))

;;;###autoload
(defun symbol-afpt-beginning-position (&optional arg ispec) 
  "Returns beginning of symbol after point if any, nil otherwise "
  (interactive "P\np")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward " \t\n\r\f")
      (thatpt-beginning 'symbol arg ispec))))

;;;###autoload
(defun symbol-afpt-end-position (&optional arg ispec) 
  "Returns end position of symbol after point if any, nil otherwise "
  (interactive "P\np")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward " \t\n\r\f")
      (thatpt-end 'symbol arg ispec))))

;;;###autoload
(defun length-of-symbol-afpt (&optional arg ispec) 
  "Returns end position of symbol after point if any, nil otherwise "
  (interactive "P\np")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward " \t\n\r\f")
      (thatpt-length 'symbol arg ispec))))

;;;###autoload
(defun copy-symbol-afpt (&optional arg ispec) 
  "Returns a copy of symbol after point if any, nil otherwise "
  (interactive "P\np")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward " \t\n\r\f")
      (thatpt-copy 'symbol arg ispec))))

;;;###autoload
(defun separate-symbol-afpt (&optional arg ispec) 
  "Returns a copy of symbol after point if any, nil otherwise "
  (interactive "P\np")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward " \t\n\r\f")
      (thatpt-separate 'symbol arg ispec))))

;;;###autoload
(defun comment-symbol-afpt (&optional arg ispec) 
  "Returns a copy of symbol after point if any, nil otherwise "
  (interactive "P\np")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward " \t\n\r\f")
      (thatpt-comment 'symbol arg ispec))))

;;;###autoload
(defun doublequote-symbol-afpt (&optional arg ispec) 
  "Doublequotes symbol after point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'symbol 'doublequote arg ispec))

;;;###autoload
(defun singlequote-symbol-afpt (&optional arg ispec) 
  "Singlequotes symbol after point if any, does nothing otherwise " 
  (interactive "P\np")
  (thatpt-delim 'symbol 'singlequote arg ispec))

;;;###autoload
(defun parenthese-symbol-afpt (&optional arg ispec) 
  "Parentizes symbol after point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'symbol 'parentize arg ispec))

;;;###autoload
(defun brace-symbol-afpt (&optional arg ispec) 
  "Braces symbol after point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'symbol 'brace arg ispec))

;;;###autoload
(defun bracket-symbol-afpt (&optional arg ispec) 
  "Brackets symbol after point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'symbol 'bracket arg ispec))

;;;###autoload
(defun mark-symbol-afpt ()
  "Marks symbol after point if any, does nothing otherwise "
  (interactive "*")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward " \t\n\r\f")
      (thatpt-mark 'symbol))))

;;;###autoload
(defun forward-symbol-afpt (&optional arg ispec) 
  "Moves forward over symbol after point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-forward 'symbol arg ispec))


;;;###autoload
(defun unibyte-afpt (&optional arg ispec) 
  "Returns unibyte after point if any, nil otherwise"
  (interactive "P\np")
  (or arg (setq arg 1)) 
  (save-excursion
    (thatpt 'unibyte arg ispec)))

;;;###autoload
(defun bounds-of-unibyte-afpt (&optional arg ispec) 
  "Returns border of unibyte after point if any, nil otherwise "
  (interactive "P\np")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward "^[:unibyte:]")
      (let ((unibyte (thatpt-bounds 'unibyte arg ispec)))
	(when ispec (message "   %s" unibyte))
	unibyte))))

;;;###autoload
(defun unibyte-afpt-beginning-position (&optional arg ispec) 
  "Returns beginning of unibyte after point if any, nil otherwise "
  (interactive "P\np")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward "^[:unibyte:]")
      (thatpt-beginning 'unibyte arg ispec))))

;;;###autoload
(defun unibyte-afpt-end-position (&optional arg ispec) 
  "Returns end position of unibyte after point if any, nil otherwise "
  (interactive "P\np")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward "^[:unibyte:]")
      (thatpt-end 'unibyte arg ispec))))

;;;###autoload
(defun length-of-unibyte-afpt (&optional arg ispec) 
  "Returns end position of unibyte after point if any, nil otherwise "
  (interactive "P\np")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward "^[:unibyte:]")
      (thatpt-length 'unibyte arg ispec))))

;;;###autoload
(defun copy-unibyte-afpt (&optional arg ispec) 
  "Returns a copy of unibyte after point if any, nil otherwise "
  (interactive "P\np")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward "^[:unibyte:]")
      (thatpt-copy 'unibyte arg ispec))))

;;;###autoload
(defun separate-unibyte-afpt (&optional arg ispec) 
  "Returns a copy of unibyte after point if any, nil otherwise "
  (interactive "P\np")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward "^[:unibyte:]")
      (thatpt-separate 'unibyte arg ispec))))

;;;###autoload
(defun comment-unibyte-afpt (&optional arg ispec) 
  "Returns a copy of unibyte after point if any, nil otherwise "
  (interactive "P\np")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward "^[:unibyte:]")
      (thatpt-comment 'unibyte arg ispec))))

;;;###autoload
(defun doublequote-unibyte-afpt (&optional arg ispec) 
  "Doublequotes unibyte after point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'unibyte 'doublequote arg ispec))

;;;###autoload
(defun singlequote-unibyte-afpt (&optional arg ispec) 
  "Singlequotes unibyte after point if any, does nothing otherwise " 
  (interactive "P\np")
  (thatpt-delim 'unibyte 'singlequote arg ispec))

;;;###autoload
(defun parenthese-unibyte-afpt (&optional arg ispec) 
  "Parentizes unibyte after point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'unibyte 'parentize arg ispec))

;;;###autoload
(defun brace-unibyte-afpt (&optional arg ispec) 
  "Braces unibyte after point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'unibyte 'brace arg ispec))

;;;###autoload
(defun bracket-unibyte-afpt (&optional arg ispec) 
  "Brackets unibyte after point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'unibyte 'bracket arg ispec))

;;;###autoload
(defun mark-unibyte-afpt ()
  "Marks unibyte after point if any, does nothing otherwise "
  (interactive "*")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward "^[:unibyte:]")
      (thatpt-mark 'unibyte))))

;;;###autoload
(defun forward-unibyte-afpt (&optional arg ispec) 
  "Moves forward over unibyte after point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-forward 'unibyte arg ispec))


;;;###autoload
(defun upper-afpt (&optional arg ispec) 
  "Returns upper after point if any, nil otherwise"
  (interactive "P\np")
  (or arg (setq arg 1)) 
  (save-excursion
    (thatpt 'upper arg ispec)))

;;;###autoload
(defun bounds-of-upper-afpt (&optional arg ispec) 
  "Returns border of upper after point if any, nil otherwise "
  (interactive "P\np")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward "^[:upper:]")
      (let ((upper (thatpt-bounds 'upper arg ispec)))
	(when ispec (message "   %s" upper))
	upper))))

;;;###autoload
(defun upper-afpt-beginning-position (&optional arg ispec) 
  "Returns beginning of upper after point if any, nil otherwise "
  (interactive "P\np")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward "^[:upper:]")
      (thatpt-beginning 'upper arg ispec))))

;;;###autoload
(defun upper-afpt-end-position (&optional arg ispec) 
  "Returns end position of upper after point if any, nil otherwise "
  (interactive "P\np")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward "^[:upper:]")
      (thatpt-end 'upper arg ispec))))

;;;###autoload
(defun length-of-upper-afpt (&optional arg ispec) 
  "Returns end position of upper after point if any, nil otherwise "
  (interactive "P\np")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward "^[:upper:]")
      (thatpt-length 'upper arg ispec))))

;;;###autoload
(defun copy-upper-afpt (&optional arg ispec) 
  "Returns a copy of upper after point if any, nil otherwise "
  (interactive "P\np")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward "^[:upper:]")
      (thatpt-copy 'upper arg ispec))))

;;;###autoload
(defun separate-upper-afpt (&optional arg ispec) 
  "Returns a copy of upper after point if any, nil otherwise "
  (interactive "P\np")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward "^[:upper:]")
      (thatpt-separate 'upper arg ispec))))

;;;###autoload
(defun comment-upper-afpt (&optional arg ispec) 
  "Returns a copy of upper after point if any, nil otherwise "
  (interactive "P\np")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward "^[:upper:]")
      (thatpt-comment 'upper arg ispec))))

;;;###autoload
(defun doublequote-upper-afpt (&optional arg ispec) 
  "Doublequotes upper after point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'upper 'doublequote arg ispec))

;;;###autoload
(defun singlequote-upper-afpt (&optional arg ispec) 
  "Singlequotes upper after point if any, does nothing otherwise " 
  (interactive "P\np")
  (thatpt-delim 'upper 'singlequote arg ispec))

;;;###autoload
(defun parenthese-upper-afpt (&optional arg ispec) 
  "Parentizes upper after point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'upper 'parentize arg ispec))

;;;###autoload
(defun brace-upper-afpt (&optional arg ispec) 
  "Braces upper after point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'upper 'brace arg ispec))

;;;###autoload
(defun bracket-upper-afpt (&optional arg ispec) 
  "Brackets upper after point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'upper 'bracket arg ispec))

;;;###autoload
(defun mark-upper-afpt ()
  "Marks upper after point if any, does nothing otherwise "
  (interactive "*")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward "^[:upper:]")
      (thatpt-mark 'upper))))

;;;###autoload
(defun forward-upper-afpt (&optional arg ispec) 
  "Moves forward over upper after point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-forward 'upper arg ispec))


;;;###autoload
(defun url-afpt (&optional arg ispec) 
  "Returns url after point if any, nil otherwise"
  (interactive "P\np")
  (or arg (setq arg 1)) 
  (save-excursion
    (thatpt 'url arg ispec)))

;;;###autoload
(defun bounds-of-url-afpt (&optional arg ispec) 
  "Returns border of url after point if any, nil otherwise "
  (interactive "P\np")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward " \t\n\r\f")
      (let ((url (thatpt-bounds 'url arg ispec)))
	(when ispec (message "   %s" url))
	url))))

;;;###autoload
(defun url-afpt-beginning-position (&optional arg ispec) 
  "Returns beginning of url after point if any, nil otherwise "
  (interactive "P\np")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward " \t\n\r\f")
      (thatpt-beginning 'url arg ispec))))

;;;###autoload
(defun url-afpt-end-position (&optional arg ispec) 
  "Returns end position of url after point if any, nil otherwise "
  (interactive "P\np")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward " \t\n\r\f")
      (thatpt-end 'url arg ispec))))

;;;###autoload
(defun length-of-url-afpt (&optional arg ispec) 
  "Returns end position of url after point if any, nil otherwise "
  (interactive "P\np")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward " \t\n\r\f")
      (thatpt-length 'url arg ispec))))

;;;###autoload
(defun copy-url-afpt (&optional arg ispec) 
  "Returns a copy of url after point if any, nil otherwise "
  (interactive "P\np")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward " \t\n\r\f")
      (thatpt-copy 'url arg ispec))))

;;;###autoload
(defun separate-url-afpt (&optional arg ispec) 
  "Returns a copy of url after point if any, nil otherwise "
  (interactive "P\np")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward " \t\n\r\f")
      (thatpt-separate 'url arg ispec))))

;;;###autoload
(defun comment-url-afpt (&optional arg ispec) 
  "Returns a copy of url after point if any, nil otherwise "
  (interactive "P\np")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward " \t\n\r\f")
      (thatpt-comment 'url arg ispec))))

;;;###autoload
(defun doublequote-url-afpt (&optional arg ispec) 
  "Doublequotes url after point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'url 'doublequote arg ispec))

;;;###autoload
(defun singlequote-url-afpt (&optional arg ispec) 
  "Singlequotes url after point if any, does nothing otherwise " 
  (interactive "P\np")
  (thatpt-delim 'url 'singlequote arg ispec))

;;;###autoload
(defun parenthese-url-afpt (&optional arg ispec) 
  "Parentizes url after point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'url 'parentize arg ispec))

;;;###autoload
(defun brace-url-afpt (&optional arg ispec) 
  "Braces url after point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'url 'brace arg ispec))

;;;###autoload
(defun bracket-url-afpt (&optional arg ispec) 
  "Brackets url after point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'url 'bracket arg ispec))

;;;###autoload
(defun mark-url-afpt ()
  "Marks url after point if any, does nothing otherwise "
  (interactive "*")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward " \t\n\r\f")
      (thatpt-mark 'url))))

;;;###autoload
(defun forward-url-afpt (&optional arg ispec) 
  "Moves forward over url after point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-forward 'url arg ispec))


;;;###autoload
(defun whitespace-afpt (&optional arg ispec) 
  "Returns whitespace after point if any, nil otherwise"
  (interactive "P\np")
  (or arg (setq arg 1)) 
  (save-excursion
    (thatpt 'whitespace arg ispec)))

;;;###autoload
(defun bounds-of-whitespace-afpt (&optional arg ispec) 
  "Returns border of whitespace after point if any, nil otherwise "
  (interactive "P\np")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward " \t\n\r\f")
      (let ((whitespace (thatpt-bounds 'whitespace arg ispec)))
	(when ispec (message "   %s" whitespace))
	whitespace))))

;;;###autoload
(defun whitespace-afpt-beginning-position (&optional arg ispec) 
  "Returns beginning of whitespace after point if any, nil otherwise "
  (interactive "P\np")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward " \t\n\r\f")
      (thatpt-beginning 'whitespace arg ispec))))

;;;###autoload
(defun whitespace-afpt-end-position (&optional arg ispec) 
  "Returns end position of whitespace after point if any, nil otherwise "
  (interactive "P\np")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward " \t\n\r\f")
      (thatpt-end 'whitespace arg ispec))))

;;;###autoload
(defun length-of-whitespace-afpt (&optional arg ispec) 
  "Returns end position of whitespace after point if any, nil otherwise "
  (interactive "P\np")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward " \t\n\r\f")
      (thatpt-length 'whitespace arg ispec))))

;;;###autoload
(defun copy-whitespace-afpt (&optional arg ispec) 
  "Returns a copy of whitespace after point if any, nil otherwise "
  (interactive "P\np")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward " \t\n\r\f")
      (thatpt-copy 'whitespace arg ispec))))

;;;###autoload
(defun separate-whitespace-afpt (&optional arg ispec) 
  "Returns a copy of whitespace after point if any, nil otherwise "
  (interactive "P\np")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward " \t\n\r\f")
      (thatpt-separate 'whitespace arg ispec))))

;;;###autoload
(defun comment-whitespace-afpt (&optional arg ispec) 
  "Returns a copy of whitespace after point if any, nil otherwise "
  (interactive "P\np")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward " \t\n\r\f")
      (thatpt-comment 'whitespace arg ispec))))

;;;###autoload
(defun doublequote-whitespace-afpt (&optional arg ispec) 
  "Doublequotes whitespace after point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'whitespace 'doublequote arg ispec))

;;;###autoload
(defun singlequote-whitespace-afpt (&optional arg ispec) 
  "Singlequotes whitespace after point if any, does nothing otherwise " 
  (interactive "P\np")
  (thatpt-delim 'whitespace 'singlequote arg ispec))

;;;###autoload
(defun parenthese-whitespace-afpt (&optional arg ispec) 
  "Parentizes whitespace after point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'whitespace 'parentize arg ispec))

;;;###autoload
(defun brace-whitespace-afpt (&optional arg ispec) 
  "Braces whitespace after point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'whitespace 'brace arg ispec))

;;;###autoload
(defun bracket-whitespace-afpt (&optional arg ispec) 
  "Brackets whitespace after point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'whitespace 'bracket arg ispec))

;;;###autoload
(defun mark-whitespace-afpt ()
  "Marks whitespace after point if any, does nothing otherwise "
  (interactive "*")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward " \t\n\r\f")
      (thatpt-mark 'whitespace))))

;;;###autoload
(defun forward-whitespace-afpt (&optional arg ispec) 
  "Moves forward over whitespace after point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-forward 'whitespace arg ispec))


;;;###autoload
(defun word-afpt (&optional arg ispec) 
  "Returns word after point if any, nil otherwise"
  (interactive "P\np")
  (or arg (setq arg 1)) 
  (save-excursion
    (thatpt 'word arg ispec)))

;;;###autoload
(defun bounds-of-word-afpt (&optional arg ispec) 
  "Returns border of word after point if any, nil otherwise "
  (interactive "P\np")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward "^[:word:]")
      (let ((word (thatpt-bounds 'word arg ispec)))
	(when ispec (message "   %s" word))
	word))))

;;;###autoload
(defun word-afpt-beginning-position (&optional arg ispec) 
  "Returns beginning of word after point if any, nil otherwise "
  (interactive "P\np")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward "^[:word:]")
      (thatpt-beginning 'word arg ispec))))

;;;###autoload
(defun word-afpt-end-position (&optional arg ispec) 
  "Returns end position of word after point if any, nil otherwise "
  (interactive "P\np")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward "^[:word:]")
      (thatpt-end 'word arg ispec))))

;;;###autoload
(defun length-of-word-afpt (&optional arg ispec) 
  "Returns end position of word after point if any, nil otherwise "
  (interactive "P\np")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward "^[:word:]")
      (thatpt-length 'word arg ispec))))

;;;###autoload
(defun copy-word-afpt (&optional arg ispec) 
  "Returns a copy of word after point if any, nil otherwise "
  (interactive "P\np")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward "^[:word:]")
      (thatpt-copy 'word arg ispec))))

;;;###autoload
(defun separate-word-afpt (&optional arg ispec) 
  "Returns a copy of word after point if any, nil otherwise "
  (interactive "P\np")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward "^[:word:]")
      (thatpt-separate 'word arg ispec))))

;;;###autoload
(defun comment-word-afpt (&optional arg ispec) 
  "Returns a copy of word after point if any, nil otherwise "
  (interactive "P\np")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward "^[:word:]")
      (thatpt-comment 'word arg ispec))))

;;;###autoload
(defun doublequote-word-afpt (&optional arg ispec) 
  "Doublequotes word after point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'word 'doublequote arg ispec))

;;;###autoload
(defun singlequote-word-afpt (&optional arg ispec) 
  "Singlequotes word after point if any, does nothing otherwise " 
  (interactive "P\np")
  (thatpt-delim 'word 'singlequote arg ispec))

;;;###autoload
(defun parenthese-word-afpt (&optional arg ispec) 
  "Parentizes word after point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'word 'parentize arg ispec))

;;;###autoload
(defun brace-word-afpt (&optional arg ispec) 
  "Braces word after point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'word 'brace arg ispec))

;;;###autoload
(defun bracket-word-afpt (&optional arg ispec) 
  "Brackets word after point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'word 'bracket arg ispec))

;;;###autoload
(defun mark-word-afpt ()
  "Marks word after point if any, does nothing otherwise "
  (interactive "*")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward "^[:word:]")
      (thatpt-mark 'word))))

;;;###autoload
(defun forward-word-afpt (&optional arg ispec) 
  "Moves forward over word after point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-forward 'word arg ispec))


;;;###autoload
(defun xdigit-afpt (&optional arg ispec) 
  "Returns xdigit after point if any, nil otherwise"
  (interactive "P\np")
  (or arg (setq arg 1)) 
  (save-excursion
    (thatpt 'xdigit arg ispec)))

;;;###autoload
(defun bounds-of-xdigit-afpt (&optional arg ispec) 
  "Returns border of xdigit after point if any, nil otherwise "
  (interactive "P\np")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward "^[:xdigit:]")
      (let ((xdigit (thatpt-bounds 'xdigit arg ispec)))
	(when ispec (message "   %s" xdigit))
	xdigit))))

;;;###autoload
(defun xdigit-afpt-beginning-position (&optional arg ispec) 
  "Returns beginning of xdigit after point if any, nil otherwise "
  (interactive "P\np")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward "^[:xdigit:]")
      (thatpt-beginning 'xdigit arg ispec))))

;;;###autoload
(defun xdigit-afpt-end-position (&optional arg ispec) 
  "Returns end position of xdigit after point if any, nil otherwise "
  (interactive "P\np")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward "^[:xdigit:]")
      (thatpt-end 'xdigit arg ispec))))

;;;###autoload
(defun length-of-xdigit-afpt (&optional arg ispec) 
  "Returns end position of xdigit after point if any, nil otherwise "
  (interactive "P\np")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward "^[:xdigit:]")
      (thatpt-length 'xdigit arg ispec))))

;;;###autoload
(defun copy-xdigit-afpt (&optional arg ispec) 
  "Returns a copy of xdigit after point if any, nil otherwise "
  (interactive "P\np")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward "^[:xdigit:]")
      (thatpt-copy 'xdigit arg ispec))))

;;;###autoload
(defun separate-xdigit-afpt (&optional arg ispec) 
  "Returns a copy of xdigit after point if any, nil otherwise "
  (interactive "P\np")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward "^[:xdigit:]")
      (thatpt-separate 'xdigit arg ispec))))

;;;###autoload
(defun comment-xdigit-afpt (&optional arg ispec) 
  "Returns a copy of xdigit after point if any, nil otherwise "
  (interactive "P\np")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward "^[:xdigit:]")
      (thatpt-comment 'xdigit arg ispec))))

;;;###autoload
(defun doublequote-xdigit-afpt (&optional arg ispec) 
  "Doublequotes xdigit after point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'xdigit 'doublequote arg ispec))

;;;###autoload
(defun singlequote-xdigit-afpt (&optional arg ispec) 
  "Singlequotes xdigit after point if any, does nothing otherwise " 
  (interactive "P\np")
  (thatpt-delim 'xdigit 'singlequote arg ispec))

;;;###autoload
(defun parenthese-xdigit-afpt (&optional arg ispec) 
  "Parentizes xdigit after point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'xdigit 'parentize arg ispec))

;;;###autoload
(defun brace-xdigit-afpt (&optional arg ispec) 
  "Braces xdigit after point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'xdigit 'brace arg ispec))

;;;###autoload
(defun bracket-xdigit-afpt (&optional arg ispec) 
  "Brackets xdigit after point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-delim 'xdigit 'bracket arg ispec))

;;;###autoload
(defun mark-xdigit-afpt ()
  "Marks xdigit after point if any, does nothing otherwise "
  (interactive "*")
  (unless (eobp)
    (save-excursion 
      (skip-chars-forward "^[:xdigit:]")
      (thatpt-mark 'xdigit))))

;;;###autoload
(defun forward-xdigit-afpt (&optional arg ispec) 
  "Moves forward over xdigit after point if any, does nothing otherwise "
  (interactive "P\np")
  (thatpt-forward 'xdigit arg ispec))




;;; thing-after-point-utils.el ends here
(provide 'thing-after-point-utils)
